require 'active_support/time'
require 'watir-webdriver'
require 'rspec'

module DriverUtility


  def initializeConfigurations(base_url)

    @driver = Watir::Browser.new :firefox
    @driver.cookies.clear
    @driver.goto(base_url)
    @driver.window.resize_to 1100, 850
    @driver.window.move_to 0,0


  end

  def gotoHome(baseUrl)
    @driver.goto(baseUrl + "/")
  end

  def getCurrentURL()
    return @driver.url
  end

  def quitDriver()
    @driver.quit
  end

  def resizeWindowTo(width, height)
    @driver.window.resize_to width, height
    sleep 1
  end

  def resizeWindowToDefault()
    resizeWindowTo(1100, 850)
    sleep 1
  end

  def parse(val)
    return JSON.parse(val)
  end

  def getVersionFromVersionFile()
    versionJsonPath = File.dirname(__FILE__) + "/../../../../dist/version.json"
    #puts versionJsonPath

    jsonfile = File.open(versionJsonPath).read
    versionJson= parse(jsonfile.to_s())

    #puts 'version json:  ' +versionJson.to_s()
    return ('v' + versionJson['version'] )

  end

  def switchWindowToWindowHandleLast()
    @driver.driver.switch_to.window @driver.driver.window_handles.last
  end

  def switchWindowToWindowHandleFirst()
    @driver.driver.switch_to.window @driver.driver.window_handles.first
  end

  def getNavStops(route)
    return route.split(">")
  end

  #### Date Functions #######

  #format=%Y-%m-%d"
  def getDateNthDaysAgo(numberOfDaysAgo, formatStr)
    dateNthDaysAgo = numberOfDaysAgo.day.ago.strftime(format=formatStr)

    return dateNthDaysAgo

  end

  def getDateNthDaysFromNow(numberOfDaysFromNow, formatStr)
    dateNthDaysFromNow = numberOfDaysFromNow.day.from_now.strftime(format=formatStr)

    return dateNthDaysFromNow
  end

  def getDateNthMonthsFromNow(numberOfDaysFromNow, formatStr)
    dateNthDaysFromNow = numberOfDaysFromNow.month.from_now.strftime(format=formatStr)

    return dateNthDaysFromNow
  end

  def getDateNthYeasFromNow(numberOfYearsFromNow, formatStr)
    dateStr = numberOfYearsFromNow.year.from_now.strftime(format=formatStr)

    #puts ("[getDateNthYearsFromNow() ]" + dateStr)

    return dateStr
  end

  def getDateNthYearsAgo(numberOfYearsAgo, formatStr)
    dateNthYearsAgo = numberOfYearsAgo.year.ago.strftime(format=formatStr)

    return dateNthYearsAgo
  end

  def getDayofWeek(dateStr)
    dateStrArray = dateStr.split("/")
    time = Time.parse(dateStrArray[2] + '-' + dateStrArray[0] + '-' + dateStrArray[1] + ' 09:00 AM')
    puts "time=" + time.to_s
    time.strftime("%A")
  end

  ###### End of Date functions ###########

end