require 'watir-webdriver'
require 'page-object'

require_relative 'common_elements'
require_relative '../module/DriverUtility'

class LearnMoreAccd < CommonElement
  include PageObject
  include DriverUtility

  def getLearnMoreSectionIntro
    self.class.p(:learnMoreIntro, :css => '.learn-more > p')
    return self.learnMoreIntro_element
  end

  ###############################################################################################################################################################################
  # The following elements will be generated dynamically in each method.
  # Author: Lian Gould
  # elements(:kAKDImg, :img, :css => 'div[heading="Kidneys and Kidney Disease"] > div:nth-of-type(2) > .panel-body.myVA > div.ng-scope > div > .learn-more-accordion__image > img')
  #
  # elements(:kAKDContent, :div, :css => 'div[heading="Kidneys and Kidney Disease"] > div:nth-of-type(2) > .panel-body.myVA > div.ng-scope > div > .learn-more-accordion__text-content')

  def getBodyContentUnderEachSection(number, headingName)
      #e.g. headingName = "Kidneys and Kidney Disease"
      self.class.elements(:kAKDContent, :div, :css => 'div[heading="' + headingName + '"] > div:nth-of-type(2) > .panel-body.myVA > div.ng-scope > div > .learn-more-accordion__text-content')

      i = 1
      kAKDContent_elements.each_with_index do |bodyContent, i|

        if i == number - 1

          return bodyContent.text.strip

          break

        end

      end

  end

  def getImgtUnderEachSection(number, headingName)
    #e.g. headingName = "Kidneys and Kidney Disease"
    self.class.elements(:kAKDImg, :img, :css => 'div[heading="' + headingName + '"] > div:nth-of-type(2) > .panel-body.myVA > div.ng-scope > div > .learn-more-accordion__image > img')

    i = 1
    kAKDImg_elements.each_with_index do |img, i|

      if i == number - 1

        return img.attribute("src")

        break

      end

    end

  end

  def getImgAltTextUnderEachSection(number, headingName)
    #e.g. headingName = "Kidneys and Kidney Disease"
    self.class.elements(:kAKDImg, :img, :css => 'div[heading="' + headingName + '"] > div:nth-of-type(2) > .panel-body.myVA > div.ng-scope > div > .learn-more-accordion__image > img')

    i = 1
    kAKDImg_elements.each_with_index do |img, i|

      if i == number - 1

        return img.attribute("alt")

        break

      end

    end

  end

  def getImgAcknowledgementUnderEachSection(number, headingName)
    #e.g. headingName = "Kidneys and Kidney Disease"
    self.class.elements(:kAKDSection, :div, :css => 'div[heading="' + headingName + '"] > div:nth-of-type(2) > .panel-body.myVA > div.ng-scope > div > .learn-more-accordion__image')

    i = 1
    kAKDSection_elements.each_with_index do |section, i|

      if i == number - 1

        return section.text.strip

        break

      end

    end

  end

  def clickImgtUnderEachSection(number, headingName)
    #e.g. headingName = "Kidneys and Kidney Disease"
    self.class.elements(:kAKDImg, :img, :css => 'div[heading="' + headingName + '"] > div:nth-of-type(2) > .panel-body.myVA > div.ng-scope > div > .learn-more-accordion__image > img')

    i = 1
    kAKDImg_elements.each_with_index do |img, i|

      if i == number - 1

        img.click

        break

      end

    end

  end

  def isImgPresent(number, headingName)

    #e.g. headingName = "Kidneys and Kidney Disease"
    self.class.elements(:kAKDImg, :img, :css => 'div[heading="' + headingName + '"] > div:nth-of-type(2) > .panel-body.myVA > div.ng-scope > div > .learn-more-accordion__image > img')

    i = 1
    kAKDImg_elements.each_with_index do |img, i|

      if i == number - 1

        return img.visible?

        break

      end

    end
  end

  ###############################################################################################################################################################################
  # The following elements will be generated dynamically in each method.
  # Author: Lian Gould
  # sample below
  # elements(:lMResource, :h4, :css => '#kidney-info--learn-more-1 > div > h4')


  def getResourceText(idName)
    self.class.element(:lMResource, :h4, :css => '#' + idName + ' > div > h4')
    return lMResource_element.text.strip
  end

  def getNthTopicTitle(idName, number)
    self.class.elements(:lMTopicTitle, :a, :css => '#' + idName + ' > div > ul > li')

    i = 1
    lMTopicTitle_elements.each_with_index do |title, i|

      if i == number - 1

        return title.text.strip

        break

      end

    end
  end

  def getNthTopicHyperLink(idName, number)
    self.class.elements(:lMTopicTitle, :a, :css => '#' + idName + ' > div > ul > li > a')

    i = 1
    lMTopicTitle_elements.each_with_index do |hplink, i|

      if i == number - 1

        return hplink.attribute("href")

        break

      end

    end
  end

  def clickNthTopicHyperLink(idName, number)
    self.class.elements(:lMTopicTitle, :a, :css => '#' + idName + ' > div > ul > li > a')

    i = 1
    lMTopicTitle_elements.each_with_index do |hplink, i|

      if i == number - 1

        hplink.click

        break

      end

    end
  end

  def getAdditionalText(idName)
    self.class.element(:lMAddiText, :p, :css => '#' + idName + ' > div > p')
    return lMAddiText_element.text.strip
  end

end