require 'watir-webdriver'
require 'page-object'

require_relative 'common_elements'
require_relative '../module/DriverUtility'

class LeftSideNav < CommonElement
  include PageObject
  include DriverUtility

  h2(:menuHeader, :css => '.snap-drawer-left h2.iOS-VO-overlap-accessible.panel-title')
  button(:leftSideNav, :id => 'nav-menu-toggle-btn')
  button(:home, :id => 'Home')
  button(:kidneyTrackers, :id => 'KidneyTrackers')
  button(:notification, :id => 'Notifications')
  button(:learnMore, :id => 'LearnMore')

  def clickAppOptionName(name)
    self.class.button(:appOptionItem, :id => name)
    appOptionItem
  end

  ############################################################
  #Kidney Trackers sub-features
  ############################################################
  button(:bPAndP, :css => '.blood-pressure-and-pulse')
  button(:weight, :css => '.weight')
  button(:glucose, :css => '.glucose')
  button(:kidneyJournal, :css => '.kidney-journal')

  ############################################################
  #Learn More sub-features
  ############################################################
  button(:kidneyInfo, :css => '.kidney-info')
  button(:nutrition, :css => '.nutrition')
  button(:laboratory, :css => '.laboratory')
  button(:socialWorkServices, :css => '.social-work-services')
  button(:pharmacy, :css => '.pharmacy')
  button(:treatment, :css => '.treatment')

  ############################################################
  #Notifications sub-features
  ############################################################
  button(:allNotifications, :css => '.all-notifications')
  button(:mKAppNotices, :css => '.mobilekidney-app-notices')
  button(:vAHealthMessages, :css => '.va-health-messages')


  def getDisplayedDateForFeature(featureName)
    self.class.div(:dateInListView, :css => featureName + ' > span > div > div > div > .tracker-nav-date')
    dateInListView
  end

  def getDisplayedReadingForFeature(featureName)
    self.class.div(:readingInListView, :css => featureName + ' > span > div > .tracker-nav-amount')
    readingInListView
  end

  def clickSubFeatureName(name)
    self.class.button(:subFeatureItem, :css => name)
    subFeatureItem
  end

  def getSubFeatureText(featureName, mainAreaName)
    if mainAreaName == "LearnMore" or mainAreaName == "Notifications"
      self.class.span(:subFeatureDisplayedText, :css => featureName + '> span > div > div > span')
      return subFeatureDisplayedText
    elsif featureName == '.blood-pressure-and-pulse'
      self.class.spans(:subFeatureDisplayedText, :css => featureName + ' .tracker-nav-title > span')
      textArr = [subFeatureDisplayedText_elements[0].text, subFeatureDisplayedText_elements[1].text]
      return textArr
    elsif mainAreaName == "KidneyTrackers"
      self.class.span(:subFeatureDisplayedText, :css => featureName + '> span > div > div > .tracker-nav-title-date > .tracker-nav-title > span')
      return subFeatureDisplayedText
    end

  end

  def isThisFeatureInTheRightPlace(number, featureName, displayedName, mainAreaName)
    isItRight = false

    if mainAreaName == "LearnMore" or mainAreaName == "Notifications"
      self.class.elements(:featureList, :span, :css => '.secondary-list > li > button')
    elsif mainAreaName == "KidneyTrackers"
      self.class.elements(:featureList, :span, :css => '.secondary-list .tracker-nav-title-wrapper')
    end

    totalCount = featureList_elements.length
    for i in 1..totalCount

      displayedFeautreText = getSubFeatureText(featureName, mainAreaName)
      if displayedFeautreText == displayedName and i == number
        isItRight = true
        break
      end
    end

    return isItRight

  end

  #Accordions
  elements(:accdExpanded, :span, :css => '.panel > div.panel-heading > h4 > span')

  elements(:accdAriaExpanded, :div, :css => '.panel > div.panel-heading' )

  elements(:accdAltText, :span, :css => '.panel > div.panel-heading > h4 > span > span')

  elements(:accdTitles, :div, :css => '.learn-more > accessible-accordion > .panel-group > div')

  def clickAccordion(number)

    i = 1
    accdExpanded_elements.each_with_index do |accd, i|

      if i == number-1
        return accd.click
        break
      end
    # i = i + 1
    end
  end

  def getAccordionTitle(number)

    i = 1
    accdTitles_elements.each_with_index do |title, i|

      if i == number-1

        return title.attribute('heading')

        break

      end

    end

  end

  def getAccordionExpandedStatus(number)
    self.class.div(:localAccordionContent, :css =>'.panel:nth-of-type(' + number.to_s + ') > .panel-collapse')

    return self.localAccordionContent?

    # i = 1
    # accdAriaExpanded_elements.each do |status|

    #   if i == number
    #     # puts "what are you=" + status.attribute("aria-expanded")
    #     return status.attribute("aria-expanded")
    #     break
    #   end

    #   i = i + 1
    # end

  end

  def getAccordionAltText(number)

    i = 1
    accdAltText_elements.each do |altText|

      if i == number
        return altText.text.strip
        break
      end
    i = i + 1
    end

  end



end