require 'watir-webdriver'
require 'page-object'
require 'rspec'

require_relative 'common_elements'
require_relative 'trackers_list_and_detail'
require_relative '../module/DriverUtility'

class Notifications < CommonElement
  include PageObject
  include DriverUtility

  #########################
  #Notification Settings
  #########################
  h2(:modalHeader, :css => '.modal-header h2')
  p(:instruTextOnSettingS1, :css => '.text-left.modal-header p:nth-of-type(1)')
  p(:instruTextOnSettingS2, :css => '.text-left.modal-header p:nth-of-type(2)')
  link(:learnMoreLink, :css => '.text-left.modal-header p:nth-of-type(3) a')
  h3(:settingLabel, :css => '.modal-body h3')
  span(:emailLabel, :name => 'emailLabel')
  text_field(:emailOnSetting, :name => 'email')
  span(:emailInstruTextOnInitSet, :css => 'form[name="initialForm"] > span:nth-of-type(2)')
  p(:emailInstruTextOnGearScreen, :css => 'form[name="settingsForm"] p')
  span(:timeZoneLabel, :name => 'timeZoneLabel')
  select_list(:timeZoneOnSettings, :name => 'timeZone')
  radio_button_group(:optIn, :name => 'optInOption')
  element(:optInLabel, :legend, :css => 'form[name="initialForm"] legend')

  button(:gearIcon, :css => 'button[title="Notification Settings"]')
  link(:learnMoreLinkOnGear, :css => 'a[ng-click="showUserGuide()"]')

  def getRequiredFieldText(formName)
    self.class.span(:requiredFieldText, :css => 'form[name="' + formName + '"] > span[is-required="true"]')
    return self.requiredFieldText
  end

  #########################
  #List view
  #########################
  select_list(:source, :name => 'source')
  radio_button_group(:notificationStatus, :css => 'input[name="statusOption"]')
  button(:notificationBttn, :css => '.navbar-nav button[title*="Notification"]')
  span(:notificationBttnText, :css => '.navbar-nav button[title*="Notification"] > span')

  def selectARadioButton(value, buttonName)
    self.class.element(:status, :radio, :css => 'input[name="' + buttonName + '"][type="radio"][value="' + value + '"]' )
    status_element.click
    sleep 0.5
  end

  def getTotalNotificationsCount()
    self.class.elements(:notificationList, :li, :css => '.list-table > ul > li')
    return notificationList_elements.length
  end

  #########################
  # Record Detail view
  #########################
  element(:notificationSource, :strong, :css => '.notification-content > p:nth-of-type(1) > strong')
  p(:systemDateTime, :css => '.notification-content > p:nth-of-type(2)')
  p(:timeZone, :css => '.notification-content > p:nth-of-type(3)')
  element(:horizaonTalLine, :hr, :css => '.notification-content > hr')
  p(:notificationText, :css => '.notification-content > p:nth-of-type(4)')
  button(:cancelBttn, :css => 'button[ng-click="cancel()"]')

  ###########################
  # Notification Detail view
  ###########################
  div(:notificationLabelText, :css => '.notification-status-wrapper .label-container .label-text')
  span(:notificationStatusLabel, :css => '.notification-status-wrapper .row span:nth-of-type(1)')
  span(:notificationStatus, :id => 'status')
  div(:instructionalText, :css => '.notification-status-wrapper .row div.ng-binding')

  div(:notificationLbTextOnDetail, :css => '.form-input-wrapper .label-container .label-text')
  div(:notificationStatusLbOnDetail, :css => '.form-input-wrapper .left')
  radio_button_group(:notificationStatusOnDetail, :css => 'input[name="notificationOption"]')
  span(:startDateRequired, :css => 'label[for="notificationStartDate"] .input-label-content span:nth-of-type(1)')
  span(:startDateLabel, :css => 'label[for="notificationStartDate"] .input-label-content span:nth-of-type(2)')
  text_field(:startDateOnDetail, :css => 'input[name="notificationStartDate"]')
  span(:notifyMeRequired, :css => 'input-select[name="notificationFrequency"] .input-label-content .required-field')
  span(:notifyMeLabel, :name => 'notificationFrequencyLabel')
  select_list(:notifyMe, :name => 'notificationFrequency')
  label(:notificationTimeLabel, :css => 'multi-time[label="Notification Time"] label.ng-binding')
  text_field(:notificationTimeWithStatusOff, :id => 'time_0')
  button(:addTimeBttn, :css => 'button[ng-click="addTimeEntry()"]')
  span(:notificationDeliveryLabel, :css => '.notification-delivery .ng-isolate-scope')
  div(:displayedEmail, :class => 'email')
  span(:instruTextOnDetail, :css => '.notification-delivery-options .col-xs-11.col-xs-offset-1.pull-right span.sr-only')
  checkbox(:notificationDeliveryCBX, :css => 'input[name="notificationDelivery"]')

  def checkNotificationDeliveryCheckBox(checkBoxValue)
    self.class.checkbox(:notificationDeliveryCBX, :css => 'input[name="notificationDelivery"][value=' + checkBoxValue + ']')
    self.check_notificationDeliveryCBX
    sleep 0.5
  end

  def unCheckNotificationDeliveryCheckBox(checkBoxValue)
    self.class.checkbox(:notificationDeliveryCBX, :css => 'input[name="notificationDelivery"][value=' + checkBoxValue + ']')
    self.uncheck_notificationDeliveryCBX
    sleep 0.5
  end

  def setNotificationTime(row, timeStr)
    self.class.text_field(:notificationTime, :id => 'time_' + row.to_s)
    self.notificationTime= timeStr
    sleep 0.5
  end

  def verifyTheNewTimeEntryAppears(row)
    self.class.text_field(:notificationTime, :css => 'input[name="time_' + row.to_s + '"]')
    return notificationTime?
  end

  def clickDeleteTimeButton(row)
    self.class.text_field(:deleteTimeBttn, :css => 'button[name="deleteTime_' + row.to_s + '"]')
    self.deleteTimeBttn
    sleep 0.5
  end

  ########################
  # Common functions
  ########################
  def verifyNotificationRow(rowNum, values)
    hasSourceColumn = values.length > 2
    dateColumn = hasSourceColumn ? 4 : 3
    self.class.span(:cellNotification, :css => '.list-table > ul > li:nth-of-type(' + rowNum.to_s + ') > span:nth-of-type(2) .cell-content')
    self.class.span(:cellSource, :css => '.list-table > ul > li:nth-of-type(' + rowNum.to_s + ') > span:nth-of-type(3) .cell-content')
    self.class.span(:cellDate, :css => '.list-table > ul > li:nth-of-type(' + rowNum.to_s + ') > span:nth-of-type(' + dateColumn.to_s + ') .cell-content span:nth-of-type(1)')
    self.class.span(:cellTime, :css => '.list-table > ul > li:nth-of-type(' + rowNum.to_s + ') > span:nth-of-type(' + dateColumn.to_s + ') .cell-content span:nth-of-type(2)')

    dateTime = self.cellDate.strip + ' ' + self.cellTime.strip
    dateTimeValue = hasSourceColumn ? values[2] : values[1]

    if self.cellNotification.strip != values[0]
      puts "FAIL, expected: " + values[0] 
      puts "Got: " + self.cellNotification
      return false
    elsif hasSourceColumn and self.cellSource.strip != values[1]
      puts "FAIL, expected: " + values[1]
      puts "Got: " + self.cellSource
      return false
    elsif dateTime.strip != dateTimeValue
      puts "FAIL, expected: " + dateTimeValue
      puts "Got: " + dateTime
      return false
    else
      return true
    end

  end

  def addANotification(dateStr, frequency, timeStrArry, deliveryMethod)
    self.selectARadioButton("On", "notificationOption")
    sleep 0.5
    self.startDateOnDetail= dateStr
    sleep 0.5

    if frequency == "Weekly" or frequency == "Monthly"
      self.notifyMe= frequency
      sleep 0.5
      self.setNotificationTime(0, timeStrArry[0])
      sleep 0.5
    elsif frequency == "Daily"
      self.notifyMe= frequency
      sleep 0.5
      puts "timeStrArry.length=" + timeStrArry.length.to_s
      for i in 0..timeStrArry.length-1
        self.setNotificationTime(i, timeStrArry[i])
        sleep 0.5
        if i < 4
          self.addTimeBttn
          sleep 0.5
        end
      end
    end

    self.checkNotificationDeliveryCheckBox(deliveryMethod)

    saveBttn

  end
end