require 'watir-webdriver'
require 'page-object'
require 'rspec'

require_relative 'common_elements'
require_relative 'trackers_list_and_detail'
require_relative '../module/DriverUtility'

class TrackerListDetail < CommonElement
  include PageObject
  include DriverUtility

  #########################
  #List view
  #########################
  div(:summaryTable, :css => '.list-table')
  button(:pdfButton, :css => 'button[title="PDF"]')

  def getDisplayedValueOnSubFeature(number)
    self.class.div(:displayedValue, :css => '.secondary-list > li:nth-of-type(' + number.to_s + ') .tracker-nav-amount')
    return self.displayedValue.strip
  end

  def getListViewTableColumnHeader(number)
    self.class.span(:columnHeader, :css => '.list-table > ul > li > span:nth-of-type(' + number.to_s + ') > span > .sr-only.ng-binding')
    return self.columnHeader.strip
  end

  def isThisColumnHidden(columnNumber)
     self.class.span(:hiddenColumnHeader, :css => '.list-table > div > div > span:nth-of-type(' + columnNumber.to_s + ')')
    return self.hiddenColumnHeader_element.attribute('class')
  end

  def getListViewTableCellValue(row, column)
    self.class.span(:cellValue, :css => '.list-table > ul > li:nth-of-type(' + row.to_s + ') > span:nth-of-type(' + column.to_s + ') > span > .cell-content > span')
    return self.cellValue.strip
  end

  def isTheNoteIconPresent(row, column)
    self.class.element(:noteIcon, :i, :css => '.list-table > ul > li:nth-of-type(' + row.to_s + ') > span:nth-of-type(' + column.to_s + ') > span > .cell-content .icon')
    return self.noteIcon?
  end

  def clickAnEntryToEditOrDelete(row)
    self.class.li(:entryOnList, :css => '.list-table > ul > li:nth-of-type(' + row.to_s + ')')
    self.entryOnList_element.click
    returnToPrevScreen_element.when_visible(timeout=10)
  end

  def searchThisValueInAllRows(columnNum, valueStr)
    foundTheValue = false

    self.class.elements(:searchCellValue, :span, :css => '.list-table > ul > li > span:nth-of-type(' + columnNum.to_s + ') > span > .cell-content > span')
    counter = searchCellValue_elements.length
    #puts "counter=" + counter.to_s

    if valueStr != "iconYes"

      searchCellValue_elements.each do |record|
        if record.text.strip == valueStr
          foundTheValue = true
          break
        end
      end
    else
      for i in 1..counter
        if isTheNoteIconPresent(i, columnNum)
          foundTheValue = true
          break
        end
      end
    end

    return foundTheValue
  end

  def verifyListAreSortedReverseChronologically(dateOrDateTimeFormat, columnNum, featureArea)
    #e.g. dateOrDateTimeFormat = "%m/%d/%Y"  (mm/dd/yyyy)
    # or dateOrDateTimeFormat = "%m/%d/%Y %I:%M %p" (mm/dd/yyyy hh:mm AM/PM)

    sortedCorrectly = true

    self.class.elements(:itemsInList, :li, :css => '.list-table > ul > li')

    boundary = itemsInList_elements.length
    # puts "boundary=" + boundary.to_s

    for number in 1..boundary
      if featureArea == 'kidneytracker'
        self.class.element(:singlelistOrder, :span, :css => '.list-table > ul > li:nth-of-type(' + number.to_s + ') > span:nth-of-type(' + columnNum.to_s + ') > span > .cell-content > span')
        dateTimeStr = singlelistOrder_element.text.strip
      elsif featureArea == 'notifications'
        self.class.element(:dateElement, :span, :css => '.list-table > ul > li:nth-of-type(' + number.to_s + ') > span:nth-of-type(' + columnNum.to_s + ') > span > .cell-content > span:nth-of-type(1)')
        self.class.element(:timeElement, :span, :css => '.list-table > ul > li:nth-of-type(' + number.to_s + ') > span:nth-of-type(' + columnNum.to_s + ') > span > .cell-content > span:nth-of-type(2)')
        dateTimeStr = dateElement_element.text.strip + ' ' + timeElement_element.text.strip
      end

      # puts "record=" + singlelistOrder_element.text.strip
      if number == 1
        previousDateTime = DateTime.strptime(dateTimeStr, format=dateOrDateTimeFormat)
        # puts "initialvalue=" + previousDateTime.to_s
      else
        thisDateTime = DateTime.strptime(dateTimeStr, format=dateOrDateTimeFormat)
        # puts "thisDateTime=" + thisDateTime.to_s

        if previousDateTime < thisDateTime then
          sortedCorrectly = false
          break
        end

        previousDateTime = thisDateTime
        # puts "previousDateTime=" + previousDateTime

      end

    end

    return sortedCorrectly

  end


  #########################
  #Detail view
  #########################
  p(:instrTextSec1, :css => 'span[ng-include="instructionsTemplate"] > p:nth-of-type(1)')
  p(:instrTextSec3, :css => 'span[ng-include="instructionsTemplate"] > p:nth-of-type(2)')


  def retrieveInstruTextSec2BullPoints(number)
    self.class.element(:instrTextSec2BullPoint, :li, :css => 'span[ng-include="instructionsTemplate"] > ul > li:nth-of-type(' + number.to_s + ')')
    return self.instrTextSec2BullPoint
  end

  def selectAGlucoseRadioButton(value, buttonName)
    self.class.element(:status, :radio, :css => 'input[name="' + buttonName + '"][type="radio"][ng-value="' + value + '"]' )
    status_element.click
    sleep 0.5
  end

  # common form elements
  text_field(:dateOnDetail, :css => 'input[name="date"]')
  text_field(:timeOnDetail, :css => 'input[name="time"]')

  span(:dateLabel, :css => 'label[for="date"] > div > .input-label-content')
  span(:timeLabel, :css => 'label[for="time"] > div > .input-label-content')

  span(:noteLabel, :css => 'span[name="NoteLabel"]')
  text_area(:note, :css => 'textarea[name="Note"]')
  span(:characterCounter, :css => '.character-counter')

  button(:saveBttn, :css => 'button[ng-click="save()"]')
  button(:cancelBttn, :css => 'button[ng-click="cancel()"]')
  button(:deleteBttn, :css => 'button[ng-click="delete()"]')
  button(:addNewEntry, :css => 'button[ng-click="getDetails()"]')

  # blood pressure and pulse elements
  span(:systolicLabel, :css => 'input-number[name="Systolic"] > div > label > span')
  text_field(:systolic, :name => 'Systolic')
  span(:diastolicLabel, :css => 'input-number[name="Diastolic"] > div > label > span')
  text_field(:diastolic, :name => 'Diastolic')
  span(:pulseLabel, :css => 'input-number[name="Pulse"] > div > label > span')
  text_field(:pulse, :name => 'Pulse')
  span(:bppPositionLabel, :css => 'input-select[name="Position"] > div > label > span')
  select_list(:bppPosition, :name => 'Position')

  # weight elements
  span(:weightLbl, :css => 'input-number[name="Weight"] > div > label > span')
  text_field(:weight, :css => 'input[name="Weight"]')

  # glucose elements
  span(:glucoseLevelLbl, :css => 'input-number[name="Glucose Level"] > div > label > span')
  span(:testMethodLabel, :css => 'input-select[name="tested"] > div > label > span')
  span(:glucoseNumericValueLbl, :css => 'input-number[name="Glucose Level"] .input-label-content > span:nth-of-type(2)')
  span(:glucoseNonNumericLbl, :css => '#glucose-non-numeric .input-label-content > span:nth-of-type(2)')
  text_field(:glucoseLevel, :css => 'input[name="Glucose Level"]')
  text_field(:glucoNonNumeric, :css => 'input[name="glucose-non-numeric"]')
  select_list(:testMethod, :css => 'select[name="tested"]')

  # kidney journal elements
  span(:requiredMarkForTitle, :css => 'input-text[name="Title"] > div label span span.required-field')
  span(:titleLabel, :css => 'span[name="TitleLabel"]')
  text_field(:titleEditBox, :css => 'input[name="Title"]')
  checkbox(:followUp, :id => 'followUp')
  span(:follwoUpLabel, :id => 'follow-up-only')
  span(:markFollowUpLabel, :id => 'follow-up')
  element(:lastUpdatedText, :small, :css => 'span[ng-if="textAreaExtra"] > small')


  ########################
  # Common functions
  ########################
  def addBloodPressurePulseEntry(dateStr, timeStr, sys, dia, pulseVal, position, noteStr)
    self.addNewEntry
    returnToPrevScreen_element.when_visible(timeout=15)

    self.dateOnDetail = ""
    sleep 0.5
    self.dateOnDetail = dateStr
    sleep 0.5
    self.timeOnDetail = ""
    sleep 0.5
    self.timeOnDetail = timeStr
    sleep 0.5
    self.systolic = sys
    sleep 0.5
    self.diastolic = dia
    sleep 0.5
    self.pulse = pulseVal
    sleep 0.5
    self.bppPosition = position
    sleep 0.5
    if note != nil
      self.note= noteStr
    end
    sleep 0.5

    self.saveBttn
  end

  def addAWeightEntry(dateStr, timeStr, weightStr, noteStr)
    self.addNewEntry
    returnToPrevScreen_element.when_visible(timeout=15)

    self.dateOnDetail= ""
    sleep 0.5
    self.dateOnDetail= dateStr
    sleep 0.5
    self.timeOnDetail= ""
    sleep 0.5
    self.timeOnDetail= timeStr
    sleep 0.5
    self.weight= weightStr
    sleep 0.5
    if note != nil
      self.note= noteStr
    end
    sleep 0.5

    self.saveBttn

  end

  def addAGlucoseEntry(dateStr, timeStr, glucoStr, methodStr, noteStr)
    self.addNewEntry
    returnToPrevScreen_element.when_visible(timeout=15)

    self.dateOnDetail= ""
    sleep 0.5
    self.dateOnDetail= dateStr
    sleep 0.5
    self.timeOnDetail= ""
    sleep 0.5
    self.timeOnDetail= timeStr
    sleep 0.5
    self.glucoseLevel= glucoStr
    sleep 0.5
    self.testMethod= methodStr
    sleep 0.5
    if note != nil
      self.note= noteStr
    end
    sleep 0.5

    self.saveBttn

  end

  def addAJournalEntry(dateStr, timeStr, titleStr, markFollowUpFlag, noteStr)
    self.addNewEntry
    returnToPrevScreen_element.when_visible(timeout=15)

    self.dateOnDetail= ""
    sleep 0.5
    self.dateOnDetail= dateStr
    sleep 0.5
    self.timeOnDetail= ""
    sleep 0.5
    self.timeOnDetail= timeStr
    sleep 0.5
    self.titleEditBox= titleStr
    sleep 0.5
    if markFollowUpFlag == true
      self.check_followUp
      sleep 0.5
    end
    if noteStr != nil
      self.note= noteStr
    end
    sleep 0.5

    self.saveBttn

  end

  def textareaMaxLengthTest(maxLength, hasCounter, textFieldtype, textFieldname)
    testPassed = 1

    testString = Array.new(maxLength){[*'0'..'9', *'a'..'z', *'A'..'Z'].sample}.join

    if hasCounter == true
      counterText = self.characterCounter
      # expect(counterText).to eq(maxLength.to_s + " characters left")
      if counterText == maxLength.to_s + " characters left"
        testPassed = testPassed * 1
      else
        testPassed = testPassed * 0
      end
    end

    if textFieldtype == "textarea"
      self.class.text_area(:fieldUnderTest, :css => 'textarea[name="'+ textFieldname + '"]')
    elsif textFieldtype == "input"
      self.class.text_field(:fieldUnderTest, :css => 'input[name="'+ textFieldname + '"]')
    end

    self.fieldUnderTest= testString + "a"
    sleep 0.5
    # expect(self.note).to eq(testString)
    if self.fieldUnderTest == testString
      testPassed = testPassed * 1
    else
      testPassed = testPassed * 0
    end

    if hasCounter == true
      counterText = self.characterCounter
      # expect(counterText).to eq("0 characters left")
      if counterText == "0 characters left"
        testPassed = testPassed * 1
      else
        testPassed = testPassed * 0
      end
    end

    return testPassed
  end

  def verifyValuesDisplayRightInTableView(rowNum, columnCount, expectedValues, hasIcon)
    allValuesDisplayed = true
    k = columnCount-1

    for i in 1..k
      displayedValue = self.getListViewTableCellValue(rowNum, i)

      expectedValue = expectedValues.split(", ")[i-1]
      if displayedValue != expectedValue then
        puts "Failure, expected: #{expectedValue}"
        puts "To equal: #{displayedValue}"
        allValuesDisplayed = false
        break
      end
    end

    if hasIcon == true and allValuesDisplayed == true
      if self.isTheNoteIconPresent(rowNum, columnCount) == false
        puts "FAILURE: Expected Note icon to be present but it's not"
        allValuesDisplayed = false
      end
    end

    return allValuesDisplayed

  end

end