require 'rspec'
require 'watir-webdriver'
require 'page-object'

require_relative './rspec_helper'
require_relative '../lib/pages/login_page'
require_relative '../lib/pages/eula'
require_relative '../lib/pages/roa'
require_relative '../lib/pages/right_side_nav'
require_relative '../lib/pages/launchpad'
require_relative '../lib/pages/common_elements'
require_relative '../lib/pages/landing_page'
require_relative '../lib/module/DBUtility'
require_relative '../lib/module/MongoUtility'

describe 'Story# CKD-2,3,4,16. [0_App_Foundation_CKD_2_3_4_16_spec.rb]', :regression=>true do
  include DriverUtility
  include DBUtility
  include MongoUtility

  app_title = "MobileKidney"

  before(:all) do

    initializeConfigurations(BASE_URL)
    # remove entry from Right Of Access table to trigger ROA show up
    deleteUserFromRightOfAccess("D123401")
    setDefaultPreferencesForPatient("D123401")
    setDefaultNotificationPreferencesForPatient("D123401", "zztest", "patient01")
    @commonElements = CommonElement.new(@driver)
    @loginpage = LoginPage.new(@driver)
    @eula = Eula.new(@driver)
    @roa = Roa.new(@driver)
    @lp = Launchpad.new(@driver)
    @rightnav = RightSideNav.new(@driver)
    @landing = LandingPage.new(@driver)

  end
  
  after(:all) do
    @driver.close
  end

  context 'Story# CKD-3|AC#CKD-35|TC#CKD-55: User is required to complete EULA in order to use the app' do
    it '. Upon using the app for the first time, EULA screen displays' do
      @eula.eulatitle_element.when_visible
      expect(@eula.eulatitle).to eq("End User License Agreement")
    end

    it '. Decline a Eula returns to LaunchPad ' do
      @eula.decline_element.when_visible
      @eula.decline

      @commonElements.jquerymobiletitle_element.when_visible(timeout=15)
      expect(@commonElements.jquerymobiletitle).to eq("Launchpad")
      @lp.mkLink_element.when_visible(timeout=10)
      @lp.mkLink

      @eula.eulatitle_element.when_visible
      expect(@eula.eulatitle).to eq("End User License Agreement")
    end

    it '. Accept a Eula lands user on the landing screen' do
      @eula.accept_element.when_visible
      @eula.accept
      @commonElements.angulartitle_element.when_visible
      expect(@commonElements.angulartitle).to eq(app_title)

    end

    it '. Verify that after user accepts a EULA, it will not show up again' do
      gotoHome(BASE_URL)
      puts "eula shall not show up"
      @commonElements.angulartitle_element.when_visible
      expect(@commonElements.angulartitle).to eq(app_title)
    end

  end

  context 'Story#CKD-4,16|AC#CKD-40|TC#CKD-111,115 Ensure ROA form is displayed. Mobile Kidney icon is available from Launchpad home page' do
    it '. If ROA form is not on record user will be presented with ROA verify sign submit' do
      @rightnav.userMenuBttn
      Watir::Wait.until {@rightnav.login?}
      @rightnav.login
      @loginpage.login_without_passing_ROA("zztest.patient01", "pass")
      @roa.nextButton_element.when_visible(timeout=15)
      expect(@commonElements.jquerymobiletitle).to eq("Right Of Access")
    end

    it '. When user clicks Decline, it returns to Launchpad' do
      @roa.firstCancel_element.when_visible
      @roa.firstCancel
      Watir::Wait.until {getCurrentURL().include?("localhost:8080/launchpad")}
      expect(getCurrentURL().include?("http://localhost:8080/launchpad")).to eq(true)
    end

    it '. When user clicks Next and then Cancel, user return to ROA first screen' do
      @lp.lpaccept_element.when_visible(timeout=15)
      @lp.lpaccept
      @lp.mkLink_element.when_visible
      @lp.mkLink
      @roa.nextButton_element.when_visible
      @roa.nextButton
      Watir::Wait.until { @roa.secondCancel? }
      @roa.secondCancel_element.when_visible
      @roa.secondCancel
      @roa.nextButton_element.when_visible(timeout=10)
      expect(@commonElements.jquerymobiletitle).to eq("Right Of Access")
    end

    it '. When user clicks through next and verify, user logs in successfully' do
      @roa.nextButton_element.when_visible
      @roa.nextButton
      Watir::Wait.until {@roa.verify?}
      @roa.verify_element.when_visible
      @roa.verify
      @loginpage.loginAs_element.when_visible(timeout=15)
      expect(@loginpage.loginAs).to eq("Logged in as patient01, zztest")
    end

    it '. When logout and logback in again, ROA shall not present. Also very the Mobile Kidney icon is available on Launchpad home page.' do
      @rightnav.userMenuBttn_element.when_visible
      @rightnav.userMenuBttn
      Watir::Wait.until {@rightnav.logout?}
      @rightnav.logout_element.when_visible
      @rightnav.logout
      sleep 2
      
      @commonElements.jquerymobiletitle_element.when_visible(timeout=15)
      expect(@commonElements.jquerymobiletitle).to eq("Launchpad")
      @lp.mkLink_element.when_visible
      expect(@lp.mkiconTitle).to eq("MobileKidney")
      expect(@lp.mkiconDesc).to eq("Manage your kidney health.")
      @lp.mkLink
      expect(@commonElements.jquerymobiletitle?).to eq(false) 
    end

  end

  context 'Story#CKD-2|AC#CKD-38|TC#CKD-114: Kidney - Login/Logout/Single Sign On' do
    it '. After authenticating in the app using single browser. Reload the app, user will be able to logon to the Mobile Kidney app through DSLogon without being authenticated again.' do
      @landing.login_element.when_visible(timeout=15)
      @landing.login
      @loginpage.login_with("zztest.patient01", "pass", "patient01, zztest", "D123401")
      @commonElements.contentLoaded_element.when_visible(timeout=10)
      expect(@commonElements.angulartitle).to eq("MobileKidney")
      gotoHome(BASE_URL)
      @landing.welcomeTextAuth_element.when_visible(timeout=15)
      expect(@loginpage.login?).to eq(false)
      expect(@loginpage.loginAs).to eq("Logged in as patient01, zztest")

    end

    it '. User can logout from right side nav' do

      @rightnav.userMenuBttn_element.when_visible(timeout=15)
      @rightnav.userMenuBttn
      @rightnav.logout_element.when_visible
      @rightnav.logout
      sleep 2
      Watir::Wait.until {@commonElements.jquerymobiletitle == "Launchpad" or @eula.lpeulatitle == "End User License Agreement"}
      if getCurrentURL().include?("eula") then
        @eula.lpaccept
      end
    end
  end


end
