#!/bin/env ruby
# encoding: utf-8

require 'rubygems'
require 'rspec'
require 'watir-webdriver'

require_relative './rspec_helper'
require_relative '../lib/pages/login_page'
require_relative '../lib/pages/eula'
require_relative '../lib/pages/landing_page'
require_relative '../lib/pages/roa'
require_relative '../lib/pages/right_side_nav'
require_relative '../lib/pages/left_side_nav'
require_relative '../lib/pages/launchpad'
require_relative '../lib/pages/common_elements'
require_relative '../lib/module/DBUtility'
require_relative '../lib/module/MongoUtility'

describe 'Story#CKD-15, 5 Landing_Page_App_Options_CKD_15_5_spec.rb', :regression=>true do
  include DriverUtility
  include DBUtility
  include MongoUtility

  before(:all) do

    initializeConfigurations(BASE_URL)
    setDefaultPreferencesForPatient("D123401")
    setDefaultNotificationPreferencesForPatient("D123401", "zztest", "patient01")

    @commonElements = CommonElement.new(@driver)
    @loginpage = LoginPage.new(@driver)
    @eula = Eula.new(@driver)
    @landing = LandingPage.new(@driver)
    @roa = Roa.new(@driver)
    @rightnav = RightSideNav.new(@driver)
    @leftnav = LeftSideNav.new(@driver)
    @lp = Launchpad.new(@driver)

  end

  after(:all) do
    @driver.close
  end

  context 'AC#CKD-36|TC#LMBB-94: Unauthenticated User - Display of Landing Page' do
    it '. Verify Page Header, Title, Current Date display correctly' do
      @eula.accept_element.when_visible
      @eula.accept
      @landing.welcomeText_element.when_visible
      expect(@commonElements.angulartitle).to eq("MobileKidney")
      expect(@landing.welcomeText).to eq("Welcome to MobileKidney")
      $today = getDateNthDaysAgo(0, "%B %d, %Y")
      expect(@landing.displayedDate).to eq($today)
    end

    it '. Verify that the main body display the correct messages and the Login button is available ' do
      expect(@landing.s1).to eq("Select Login to access the MobileKidney app.")
      expect(@landing.s2).to eq("Learn more about this application by selecting the button above.")
      expect(@landing.s3).to eq("Wishing you good health and welfare,")
      expect(@landing.s4).to eq("Your VA Care Team")
      expect(@landing.login?).to eq(true)
    end

    it '. Verify that About, Launchpad and Login buttons display on the Right Side Menu' do
      @rightnav.userMenuBttn
      @rightnav.menuheader_element.when_visible(timeout=10)
      expect(@rightnav.about?).to eq(true)
      expect(@rightnav.about_element.text.strip).to eq("About")
      expect(@rightnav.help?).to eq(false)
      expect(@rightnav.launchpad?).to eq(true)
      expect(@rightnav.launchpad_element.text.strip).to eq("Launchpad")
      expect(@rightnav.login?).to eq(true)
      expect(@rightnav.login_element.text.strip).to eq("Login")
    end

    it '. Verify the App Option button is not present' do
      expect(@leftnav.leftSideNav_element.attribute("ng-hide")).to eq("hideAppOptions()")
    end

  end

  context 'AC#CKD-37|TC#CKD-94: Authenticated User - Display of Landing Page' do
    it '. Click Login from the right side nav. Verify the page header, welcome text and Current system date display correctly' do
      @rightnav.login
      @loginpage.login_with("zztest.patient01", "pass", "patient01, zztest", "D123401")
      @commonElements.angulartitle_element.when_visible
      expect(@commonElements.angulartitle).to eq("MobileKidney")
      expect(@landing.welcomeTextAuth).to eq("Welcome zztest patient01")

    end

    it '. Verify that About, Help, Launchpad and Login buttons display on the Right Side Menu' do
      @rightnav.userMenuBttn
      @rightnav.menuheader_element.when_visible(timeout=10)
      expect(@rightnav.about?).to eq(true)
      expect(@rightnav.about_element.text.strip).to eq("About")
      expect(@rightnav.help?).to eq(true)
      expect(@rightnav.help_element.text.strip).to eq("Help")
      expect(@rightnav.launchpad?).to eq(true)
      expect(@rightnav.launchpad_element.text.strip).to eq("Launchpad")
      expect(@rightnav.logout?).to eq(true)
      expect(@rightnav.logout_element.text.strip).to eq("Logout")
    end

  end

  context 'AC#CKD-41|TC#CKD-203: App Options' do
    it '. Verify the App Option button is present. Tapping on it opens all the options: home, MobileKidney Trackers, Notifictions and Learn More' do
      @rightnav.userMenuBttn
      @leftnav.leftSideNav_element.when_visible(timeout=10)
      expect(@leftnav.leftSideNav?).to eq(true)
      @leftnav.leftSideNav

      @leftnav.menuHeader_element.when_visible
      expect(@leftnav.home?).to eq(true)
      expect(@leftnav.home_element.text.strip.split("\n")[0]).to eq("Home")
      expect(@leftnav.kidneyTrackers?).to eq(true)
      expect(@leftnav.kidneyTrackers_element.text.strip).to eq("Kidney Trackers")
      expect(@leftnav.notification?).to eq(true)
      expect(@leftnav.notification_element.text.strip).to eq("Notifications")
      expect(@leftnav.learnMore?).to eq(true)
      expect(@leftnav.learnMore_element.text.strip).to eq("Learn More")
    end

  end



end
