#!/bin/env ruby
# encoding: utf-8
require 'rspec'
require 'watir-webdriver'
require 'page-object'

require_relative './rspec_helper'
require_relative '../lib/pages/login_page'
require_relative '../lib/pages/right_side_nav'
require_relative '../lib/pages/common_elements'
require_relative '../lib/pages/common_tests'
require_relative '../lib/pages/modal_dialog'
require_relative '../lib/pages/resources'

describe 'Story #CKD-14 Resources_CKD_14_spec.rb', :regression => true do
	include DriverUtility

	before(:all) do

		initializeConfigurations(BASE_URL)

		@commonElements = CommonElement.new(@driver)
		@loginpage = LoginPage.new(@driver)
		@rightnav = RightSideNav.new(@driver)
		@commonTest = CommonTest.new(@driver)
		@modal = Modal.new(@driver)
		@resources = Resources.new(@driver)

		@commonTest.passByLandingPageAndAuthenticate("zztest.patient01", "pass", "patient01, zztest", "D123401")
	end

	after(:all) do
		@driver.close
	end

	sections = [
		{ :name => "Kidney Disease Websites", :worksheet => "kidneyDisease" },
		{ :name => "Diabetes Websites", :worksheet => "diabetes" },
		{ :name => "Kidney Info Resources", :worksheet => "kidneyInfo" },
		{ :name => "Nutrition Resources", :worksheet => "nutrition" },
		{ :name => "Laboratory Resources", :worksheet => "laboratory" },
		{ :name => "Social Work Resources", :worksheet => "socialWork" },
		{ :name => "Pharmacy Resources", :worksheet => "pharmacy" },
		{ :name => "Treatment Resources", :worksheet => "treatment" }
	]

	dataSheetFilePath = File.dirname(__FILE__) + '/../datasheet/Resources_Content.xls'
  	book = Spreadsheet.open dataSheetFilePath

	context 'AC #CKD-845 | TC #CKD-1469 -- Resources Modal' do
		it '. Verify Resources link is in Right Hand menu and navigable' do
			@commonElements.angulartitle_element.when_visible
			@rightnav.userMenuBttn
			expect(@resources.resourcesLink?).to eq(true)

			@resources.resourcesLink
			expect(@resources.disclaimer?).to eq(true)
			expect(@resources.urgentGroup?).to eq(true)
			expect(@resources.accordion?).to eq(true)
		end
	end

	context 'AC #CKD-846 | TC #CKD-1469 -- Resources Modal Urgent Contacts' do
		it '. Verify disclaimer and urgent contacts content' do
			expect(@resources.disclaimer_element.text).to eq('*Non-VA Resource: The VA does not endorse and is not responsible for the content of linked websites.')
			
			urgentGroupParts = @resources.urgentGroup_element.text.split("\n")
			expect(urgentGroupParts[0]).to eq('Urgent Contacts')
			expect(urgentGroupParts[1]).to eq('Veteran Crisis Line')
			expect(urgentGroupParts[2]).to eq('1-800-273-8255 and Press 1')
			expect(urgentGroupParts[3]).to eq('Confidential support is available 24 hours a day, 7 days a week, 365 days a year through the Veterans Crisis Line, Online Chat, and text (838255).')
		end
	end

	context 'AC #CKD-847 | #CKD-847 | #CKD-849 | #CKD-850 | #CKD-851 | #CKD-852 | #CKD-853 | #CKD-854 | #CKD-855 | #CKD-856 || TC #CKD-1469 -- Resources Modal Accordion Sections' do
		sections.each_with_index do |section, index|
			it '. Verify accordion content for section - ' + section[:name] do

				header = @resources.getAccordionHeader(index)
				expect(section[:name]).to eq(header)

				@resources.openAccordionByIndex(index)
				sleep 1

				worksheetName = section[:worksheet]
				worksheet = book.worksheet worksheetName

				worksheet.each_with_index do | row, idx |
					link = @resources.getAccordionHyperlink(index, idx)
					expectedText = row[0].rstrip  # strip trailing spaces from Excel cell
					expectedHref = row[1]

					expect(link.text).to eq(expectedText)
					expect(link.attribute('href')).to eq(expectedHref)
				end
			end
		end
	end


end
