#!/bin/env ruby
# encoding: utf-8

require 'rubygems'
require 'rspec'
require 'watir-webdriver'

require_relative '../rspec_helper'
require_relative '../../lib/pages/left_side_nav'
require_relative '../../lib/pages/common_elements'
require_relative '../../lib/pages/common_tests'
require_relative '../../lib/pages/landing_page'
require_relative '../../lib/module/DBUtility'
require_relative '../../lib/module/MongoUtility'

describe 'Story#CKD-913,1161 Dashboard_And_Phone_View_Carousel_CKD_913_1161_spec.rb', :regression=>true do
  include DriverUtility
  include DBUtility
  include MongoUtility

  before(:all) do

    initializeConfigurations(BASE_URL)
    resetCollection("chemlabs", "medicalhistorydb", "spec/snapshots/glucose/chemlabs.bson")
    resetCollection("vitalsigns", "medicalhistorydb", "spec/snapshots/vitalsigns/vitalsigns.bson")
    resetCollection("vitalsignsbundles", "medicalhistorydb", "spec/snapshots/vitalsignsbundles/vitalsignsbundles.bson")

    @commonElements = CommonElement.new(@driver)
    @commonTest = CommonTest.new(@driver)
    @landing = LandingPage.new(@driver)

    @commonTest.passByLandingPageAndAuthenticate("zztest.patient13", "pass", "patient13, zztest", "PATID12")

    @commonTest.waitForContentLoaded
    @commonElements.contentLoaded_element.when_present(timeout=15)

    $todayLong = getDateNthDaysAgo(0, "%B %d, %Y")
    $todayShort = getDateNthDaysAgo(0, "%m/%d/%y")
    $yesterdayShort = getDateNthDaysAgo(1, "%m/%d/%y")

  end

  after(:all) do
    @driver.close
  end

  context 'AC#CKD-1510,1454|TC#CKD-1562:   Welcome user to Homepage for MobileKidney and Summary Section Title' do
    it '. Verify the page header displayed correctly' do
      expect(@commonElements.angulartitle).to eq("MobileKidney")
    end

    it '. Verify that the Title has this text: Welcome <user first name> <user last name>' do

      expect(@landing.welcomeTextAuth).to eq("Welcome zztest patient13")
    end

    it '. Verify that the current date displays correctly and in the right format' do
      expect(@landing.systemDateAuth).to eq($todayLong)
    end

    it '. Verify a horizontal line displays' do
      expect(@landing.horizontalLine?).to eq(true)
    end

    it '. Verify the Summary section has the title Summary' do
      expect(@landing.summaryText).to eq("Summary")
    end

  end

  context 'AC#CKD-1455|TC#CKD-1562:  Blood Pressure Tracker Summary' do
    it '. Verify that Blood Pressure Summary displays the correct Title, Reading and Last updated date' do
      if $yesterdayShort == "01/27/15"
        displayedDate = "Yesterday"
      else
        displayedDate = "01/27/15"
      end

      expect(@landing.retrieveSummaryValuesFromDashboard(2)[0]).to eq("Blood Pressure")
      expect(@landing.retrieveSummaryValuesFromDashboard(2)[1]).to eq("180/90 mmHg")
      expect(@landing.retrieveSummaryValuesFromDashboard(2)[2]).to eq("Last updated: " + displayedDate)
    end

  end

  context 'AC#CKD-1456|TC#CKD-1562:  Weight Tracker Summary' do
    it '. Verify that Weight Summary displays the correct Title, Reading and Last updated date' do
      if $todayShort == "01/30/15"
        displayedDate = "Today"
      elsif $yesterdayShort == "01/16/15"
        displayedDate = "Yesterday"
      else
        displayedDate = "01/16/15"
      end

      expect(@landing.retrieveSummaryValuesFromDashboard(3)[0]).to eq("Weight")
      expect(@landing.retrieveSummaryValuesFromDashboard(3)[1]).to eq("196 lbs")
      expect(@landing.retrieveSummaryValuesFromDashboard(3)[2]).to eq("Last updated: " + displayedDate)

    end

  end

  context 'AC#CKD-1457|TC#CKD-1562: Glucose Tracker Summary' do
    it '. Verify that Glucose Summary displays the correct Title, Reading and Last updated date' do

      expect(@landing.retrieveSummaryValuesFromDashboard(4)[0]).to eq("Glucose")
      expect(@landing.retrieveSummaryValuesFromDashboard(4)[1]).to eq("180 mg/dl")
      expect(@landing.retrieveSummaryValuesFromDashboard(4)[2]).to eq("Last updated: 01/16/15")

    end
  end

  context 'AC#CKD-1458|TC#CKD-1562: Disclaimer for Kidney Trackers Summary' do
    it '. Verify the disclaimer has the correct texts.' do
      expect(@landing.disclaimerSec1).to eq("Information entered may not be reviewed by your provider but can be shared at your next appointment. For immediate medical needs, contact your provider.")
      expect(@landing.disclaimerSec2).to eq("Use the menu buttons on the top left or right to explore the app.")
    end
  end

  context 'AC#1438,1439,1440|TC#1575: Phone user - Status Image Navigation' do
    it '. Verify that in Phone form factor, the carousel view is present and functional according to the ACs' do
      #Reset to Phone size
      resizeWindowTo(320, 480)
      sleep 1
      @landing.nextScreenBttn_element.when_visible(timeout=10)
      expect(@landing.verifyTheCorrectSummaryBoxDisplaysWhenClickingNext()).to eq(3)
    end
  end

end
