#!/bin/env ruby
# encoding: utf-8

require 'rubygems'
require 'rspec'
require 'watir-webdriver'

require_relative '../rspec_helper'
require_relative '../../lib/pages/left_side_nav'
require_relative '../../lib/pages/common_elements'
require_relative '../../lib/pages/common_tests'
require_relative '../../lib/pages/modal_dialog'
require_relative '../../lib/pages/filters'
require_relative '../../lib/pages/error_validations'
require_relative '../../lib/pages/trackers_list_and_detail'
require_relative '../../lib/module/DBUtility'
require_relative '../../lib/module/MongoUtility'

describe 'Story#CKD-755,1758 Glucose_Add_Edit_Delete_CKD_755_1758_spec.rb', :acceptance => true do
  include DriverUtility
  include DBUtility
  include MongoUtility

  before(:all) do

    initializeConfigurations(BASE_URL)
    removeCollection("chemlabs", "medicalhistorydb")

    @commonElements = CommonElement.new(@driver)
    @commonTest = CommonTest.new(@driver)
    @leftnav = LeftSideNav.new(@driver)
    @modal = Modal.new(@driver)
    @filter = Filters.new(@driver)
    @error = Errors.new(@driver)
    @tklistDetail = TrackerListDetail.new(@driver)

    @commonTest.passByLandingPageAndAuthenticate("zztest.patient14", "pass", "patient14, zztest", "PATID13")

    @commonTest.waitForContentLoaded
    @leftnav.leftSideNav
    @leftnav.home_element.when_visible

    @commonTest.navigateToAsubFeature("KidneyTrackers", ".glucose")
    @commonElements.contentLoaded_element.when_present

    $todayLong = getDateNthDaysAgo(0, "%m/%d/%Y")
    $yesterdayShort = getDateNthDaysAgo(1, "%m/%d/%y")
    $yesterdayLong = getDateNthDaysAgo(1, "%m/%d/%Y")
    $tomorrow = getDateNthDaysFromNow(1, "%m/%d/%Y")
    $sixYearsAgo = getDateNthYearsAgo(6, "%m/%d/%Y")
    $sixYears1dayAgo = getDateNthDaysAgo(2192, "%m/%d/%Y")
    $oneYearAgo = getDateNthYearsAgo(1, "%m/%d/%Y")

  end

  after(:all) do
    @driver.close
  end

  context 'AC#CKD-1399,1831|TC#CKD-1384,1843:  Add New Entry for Kidney Glucose Tracker' do
    it '. Verify the Add (+) button is available' do
      expect(@tklistDetail.addNewEntry?).to eq(true)
    end

    it '. Verify the detail screen header displays correctly' do
      @tklistDetail.addNewEntry
      @commonElements.primaryHeader_element.when_visible(timeout=10)
      expect(@commonElements.primaryHeader).to eq("Add Glucose Entry")
    end

    it '. Verify that required field indicator is present and all fields are present with the correct label' do
      expect(@commonElements.requiredFieldLabel).to eq("* required field")
      expect(@tklistDetail.dateLabel).to eq("* Date:")
      expect(@tklistDetail.timeLabel).to eq("* Time:")
      expect(@tklistDetail.glucoseLevelLbl.include?("* Results (mg/dl):")).to eq(true)
      expect(@tklistDetail.testMethodLabel).to eq("* Tested:")
      expect(@tklistDetail.noteLabel).to eq("Note:")

    end

    it '. Verify that the MM/DD/YYYY displays as the format guidance at Date field; HH:MM AM/PM displays as the format guidance at Time field' do
      expect(@tklistDetail.dateOnDetail_element.attribute('placeholder')).to eq("MM/DD/YYYY")
      expect(@tklistDetail.timeOnDetail_element.attribute('placeholder')).to eq("HH:MM AM/PM")
    end


    it '. Select the Numeric Value radio button. Verify that the edit box has the correct lable and user can enter numeric values ' do
      @tklistDetail.selectAGlucoseRadioButton("true", "numericValue")
      sleep 0.5
      expect(@tklistDetail.glucoseNumericValueLbl).to eq("Results (mg/dl):")
      expect(@tklistDetail.glucoseLevel_element.attribute("placeholder")).to eq("Between 0 and 600")
      @tklistDetail.glucoseLevel = "601"
      @tklistDetail.saveBttn
      @error.errorHeader_element.when_visible
      errMsg  = "Results (mg/dl) is outside the expected range. Please enter a value between 0 and 600."
      expect(@error.isThisErrorDisplayed(errMsg)).to eq(true)
    end

    it '. Select the Non-Numeric Value radio button. Verify that the edit box has the correct label and user can enter non-numeric values ' do
      @tklistDetail.selectAGlucoseRadioButton("false", "numericValue")
      sleep 0.5
      expect(@tklistDetail.glucoseNonNumericLbl).to eq("Monitor Reading:")
      expect(@tklistDetail.glucoNonNumeric_element.attribute("placeholder")).to eq("Example: High")
      @tklistDetail.glucoNonNumeric = "Normal"
      @tklistDetail.testMethod="After Meal"
      @tklistDetail.saveBttn
      @commonTest.waitForContentLoaded
      sleep 1
      expect(@tklistDetail.getDisplayedValueOnSubFeature(3)).to eq("Normal")
    end

    it '. Verify the Tested drop down list set on Select as default and had the right choices to select from.' do
      @tklistDetail.addNewEntry
      @commonTest.waitForContentLoaded
      expect(@tklistDetail.testMethod).to eq("Select")
      expect(@tklistDetail.testMethod_options.include?("Fasting (8 hours)")).to eq(true)
      expect(@tklistDetail.testMethod_options.include?("After Meal")).to eq(true)
      expect(@tklistDetail.testMethod_options.include?("Unknown")).to eq(true)
    end

    it '. Verify that Date is required and can not be future date; Time is required.' do
      @tklistDetail.dateOnDetail= ""
      sleep 0.5
      @tklistDetail.timeOnDetail= ""
      sleep 0.5
      @tklistDetail.saveBttn
      @error.errorHeader_element.when_visible
      expect(@error.isThisErrorDisplayed("Date field is required.")).to eq(true)
      expect(@error.isThisErrorDisplayed("Time field is required.")).to eq(true)

      @tklistDetail.dateOnDetail= $tomorrow
      sleep 0.5
      @tklistDetail.saveBttn
      errMsg  = "Date must be between " + $sixYearsAgo + " and " + $todayLong + "."
      #puts "errMsg=" + errMsg
      expect(@error.isThisErrorDisplayed(errMsg)).to eq(true)
    end

    it '. Verify the Note field has a character counter and it allows max 250 characters' do
      expect(@tklistDetail.characterCounter?).to eq(true)
      expect(@tklistDetail.textareaMaxLengthTest(250, true, "textarea","Note")).to eq(1)
      @tklistDetail.cancelBttn
      @tklistDetail.addNewEntry_element.when_visible(timeout=10)
    end

    it '. Happy path, to add three entries. Verify the values are saved and they display correctly in the Table View' do
      @tklistDetail.addAGlucoseEntry($yesterdayLong, "07:00 AM", 69, "Fasting (8 hours)", "")
      valueStr = '69, Fasting (8 hours), ' + $yesterdayLong + ' 07:00 AM'
      @tklistDetail.summaryTable_element.when_visible(timeout=15)
      expect(@tklistDetail.verifyValuesDisplayRightInTableView(2, 4, valueStr, false)).to eq(true)

      @tklistDetail.addAGlucoseEntry($yesterdayLong, "01:00 PM", 180, "After Meal", "")
      valueStr = '180, After Meal, ' + $yesterdayLong + ' 01:00 PM'
      @tklistDetail.summaryTable_element.when_visible(timeout=15)
      expect(@tklistDetail.verifyValuesDisplayRightInTableView(2, 4, valueStr, false)).to eq(true)

      @tklistDetail.addAGlucoseEntry($yesterdayLong, "08:00 PM", 150, "Unknown", "Walked after dinner")
      valueStr = '150, Unknown, ' + $yesterdayLong + ' 08:00 PM'
      @tklistDetail.summaryTable_element.when_visible(timeout=15)
      expect(@tklistDetail.verifyValuesDisplayRightInTableView(2, 4, valueStr, true)).to eq(true)
    end

    it '. Verify that Date and Time values must be unique. Users cannot save more than one entry for a given date/time.' do
      @tklistDetail.addAGlucoseEntry($yesterdayLong, "08:00 PM", 100, "After Meal", "Walked after dinner")
      @commonTest.waitForContentLoaded
      if @error.errorHeader? != true
        expect("Duplicate date/time were saved without throwing an error").to eq("Duplicate date/time is not allowed")
      else
        errMsg  = "An entry has already been saved with the same date and time. Please change your date and/or time and save again."
        expect(@error.isThisErrorDisplayed(errMsg)).to eq(true)
        @tklistDetail.cancelBttn
        @tklistDetail.summaryTable_element.when_visible(timeout=15)
      end
    end

  end

  context 'AC#CKD-1400|TC#CKD-1384:  Edit an Entry for Kidney Glucose Tracker' do
    it '. Verify that All data elements available in Add Entry mode are visible.' do
      @tklistDetail.clickAnEntryToEditOrDelete(2) # '$yesterdayLong, "08:00 PM", 150, "Unknown"'
      @commonTest.waitForContentLoaded
      expect(@commonElements.primaryHeader).to eq("Edit Glucose Entry")
      expect(@tklistDetail.dateLabel).to eq("* Date:")
      expect(@tklistDetail.timeLabel).to eq("* Time:")
      expect(@tklistDetail.glucoseLevelLbl.include?("* Results (mg/dl):")).to eq(true)
      expect(@tklistDetail.testMethodLabel).to eq("* Tested:")
      expect(@tklistDetail.noteLabel).to eq("Note:")
    end

    it '. Verify that all values previously saved are visible.' do
      expect(@tklistDetail.dateOnDetail).to eq($yesterdayLong)
      expect(@tklistDetail.timeOnDetail).to eq("08:00 PM")
      expect(@tklistDetail.glucoseLevel).to eq("150")
      expect(@tklistDetail.testMethod).to eq("Unknown")
      expect(@tklistDetail.note).to eq("Walked after dinner")
    end

    it '. Modify a value and save. Verify the updated value displays in the table view' do
      @tklistDetail.glucoseLevel = 200
      @tklistDetail.saveBttn
      @commonTest.waitForContentLoaded
      valueStr = "200, Unknown, " + $yesterdayLong + " 08:00 PM"
      expect(@tklistDetail.verifyValuesDisplayRightInTableView(2, 4, valueStr, true)).to eq(true)
    end

  end

  context 'AC#CKD-1401|TC#CKD-1384:  Cancel and Delete for Kidney Glucose' do
    it '. Verify that When a user selects Cancel, no updates are made to the record.' do
      @tklistDetail.clickAnEntryToEditOrDelete(2)
      @tklistDetail.cancelBttn
      @commonTest.waitForContentLoaded
      # Nothing has changed
      valueStr = "200, Unknown, " + $yesterdayLong + " 08:00 PM"
      expect(@tklistDetail.verifyValuesDisplayRightInTableView(2, 4, valueStr, true)).to eq(true)
    end

    it '. Verify that When a user selects Delete, the system prompts the user to confirm the Delete by displaying a modal:' do
      @tklistDetail.clickAnEntryToEditOrDelete(2)
      @tklistDetail.deleteBttn
      @modal.modalTitle_element.when_visible
      expect(@modal.modalTitle).to eq("Confirmation")
      expect(@modal.section1).to eq("Are you sure you want to remove this entry? Select YES to remove the entry or NO to return to the entry screen.")
      @modal.ok2
      @modal.modalTitle_element.when_not_visible
      expect(@commonElements.primaryHeader).to eq("Edit Glucose Entry")

      @tklistDetail.deleteBttn
      @modal.modalTitle_element.when_visible
      @modal.yes
      valueStr = $yesterdayLong + "08:00 PM"
      expect(@tklistDetail.searchThisValueInAllRows(1, valueStr)).to eq(false)
    end
  end

  context 'AC#CKD-1402 |TC#CKD-1384: Navigation' do
    it '. Verify that < is shown on the list screen when on a phone view and has the correct alt text. Clicking it returns the user to the list view' do
      @tklistDetail.addNewEntry_element.when_visible
      @tklistDetail.addNewEntry
      @commonTest.waitForContentLoaded
      #Reset to Phone size
      resizeWindowTo(320, 480)
      sleep 1
      expect(@commonElements.returnToPrevScreen?).to eq(true)
      expect(@commonElements.returnToPrevScreen_element.attribute('title')).to eq("Return to Previous Screen")

      @commonElements.returnToPrevScreen
      @commonElements.primaryHeader_element.when_visible(timeout=10)
      expect(@commonElements.primaryHeader).to eq("Glucose")

    end

    it '. Verify user is prompt with a modal when clicking < with unsaved data' do
      @tklistDetail.clickAnEntryToEditOrDelete(2)
      @tklistDetail.glucoseLevel = 230
      @commonElements.returnToPrevScreen
      @modal.modalTitle_element.when_visible
      expect(@modal.modalTitle).to eq("Confirmation")
      expect(@modal.section1).to eq("You have not saved your changes. If you wish to continue without saving select CONTINUE, otherwise select RETURN to return to the entry screen.")

      #click Return
      @modal.ok2
      @modal.modalTitle_element.when_not_visible
      expect(@commonElements.primaryHeader).to eq("Edit Glucose Entry")

      @tklistDetail.glucoseLevel = 230
      @commonElements.returnToPrevScreen
      @modal.modalTitle_element.when_visible
      #click Continue
      @modal.yes
      @modal.modalTitle_element.when_not_visible
      expect(@commonElements.primaryHeader).to eq("Glucose")

    end

    it '. Verify that when navigate away from a screen with unsaved data, the same modal pops up' do
      @tklistDetail.clickAnEntryToEditOrDelete(2)
      @tklistDetail.glucoseLevel= 230
      #Click the left nav button without saving
      @leftnav.leftSideNav
      @leftnav.home_element.when_visible
      @leftnav.learnMore
      @modal.modalTitle_element.when_visible
      expect(@modal.modalTitle).to eq("Confirmation")
      expect(@modal.section1).to eq("You have not saved your changes. If you wish to continue without saving select CONTINUE, otherwise select RETURN to return to the entry screen.")


      #Reset to the default size
      resizeWindowToDefault()

    end


  end


end
