#!/bin/env ruby
# encoding: utf-8

require 'rubygems'
require 'rspec'
require 'watir-webdriver'

require_relative '../rspec_helper'
require_relative '../../lib/pages/login_page'
require_relative '../../lib/pages/eula'
require_relative '../../lib/pages/landing_page'
require_relative '../../lib/pages/roa'
require_relative '../../lib/pages/right_side_nav'
require_relative '../../lib/pages/left_side_nav'
require_relative '../../lib/pages/launchpad'
require_relative '../../lib/pages/common_elements'
require_relative '../../lib/pages/common_tests'
require_relative '../../lib/module/DBUtility'

describe 'Story#CKD-754 Kidney_Trackers_Feature_List_CKD_754_spec.rb', :regression=>true do
  include DriverUtility
  include DBUtility


  before(:all) do

    initializeConfigurations(BASE_URL)

    @commonElements = CommonElement.new(@driver)
    @commonTest = CommonTest.new(@driver)
    @loginpage = LoginPage.new(@driver)
    @eula = Eula.new(@driver)
    @landing = LandingPage.new(@driver)
    @roa = Roa.new(@driver)
    @rightnav = RightSideNav.new(@driver)
    @leftnav = LeftSideNav.new(@driver)
    @lp = Launchpad.new(@driver)

    @commonTest.passByLandingPageAndAuthenticate("zztest.patient01", "pass", "patient01, zztest", "D123401")

    @commonTest.waitForContentLoaded
    @leftnav.leftSideNav

    @leftnav.home_element.when_visible

    @leftnav.clickAppOptionName("KidneyTrackers")

    @commonElements.secondaryHeader_element.when_visible(timeout=10)

  end

  after(:all) do
    @driver.close
  end

  context 'AC#CKD-1262|TC#CKD-1242: When the user selects the Kidney Trackers feature from the left panel navigation, the system displays the Feature groups in the Main Screen' do
    it '. Verify Page Header displays correctly' do
      expect(@commonElements.secondaryHeader).to eq("Kidney Trackers")
    end

    it '. Verify that features displayed have the correct name ' do

      expect(@leftnav.getSubFeatureText('.blood-pressure-and-pulse', 'KidneyTrackers')).to eq(["Blood Pressure", "Pulse"])
      expect(@leftnav.getSubFeatureText('.weight', 'KidneyTrackers')).to eq("Weight")
      expect(@leftnav.getSubFeatureText('.glucose','KidneyTrackers')).to eq("Glucose")
      expect(@leftnav.getSubFeatureText('.kidney-journal', 'KidneyTrackers')).to eq("Kidney Journal")

    end

    it '. Verify that feature names display in the right order' do
      expect(@leftnav.isThisFeatureInTheRightPlace(1, '.blood-pressure-and-pulse', ['Blood Pressure', 'Pulse'], 'KidneyTrackers')).to eq(true)
      expect(@leftnav.isThisFeatureInTheRightPlace(2, '.weight', 'Weight','KidneyTrackers')).to eq(true)
      expect(@leftnav.isThisFeatureInTheRightPlace(3, '.glucose', 'Glucose','KidneyTrackers')).to eq(true)
      expect(@leftnav.isThisFeatureInTheRightPlace(4, '.kidney-journal', 'Kidney Journal','KidneyTrackers')).to eq(true)

    end


  end

  context 'AC#CKD-1263|TC#CKD-1242:  In the tablet and desktop view the following instructional text is displayed in the Detail screen. Default text displays when no item is selected' do
    it '. Verify that the default text displays correctly' do
      @commonElements.defaultTextToSelectItem_element.when_visible(timeout=10)
      expect(@commonElements.defaultTextToSelectItem).to eq("Select an item from the Kidney Trackers list to view details or add a new entry.")
    end

  end

end
