#!/bin/env ruby
# encoding: utf-8

require 'rubygems'
require 'rspec'
require 'watir-webdriver'
require 'page-object'
require 'spreadsheet'

require_relative '../rspec_helper'
require_relative '../../lib/pages/login_page'
require_relative '../../lib/pages/eula'
require_relative '../../lib/pages/landing_page'
require_relative '../../lib/pages/roa'
require_relative '../../lib/pages/launchpad'
require_relative '../../lib/pages/common_elements'
require_relative '../../lib/pages/common_tests'
require_relative '../../lib/pages/modal_dialog'
require_relative '../../lib/pages/left_side_nav'
require_relative '../../lib/pages/learn_more_accordions'


describe 'Story#CKD-23 Kidney_And_Kidney_Disease_Content_CKD_23_spec.rb', :regression=>true do
  include DriverUtility

  headingName = "Kidneys and Kidney Disease"

  before(:all) do

    initializeConfigurations(BASE_URL)

    @commonElements = CommonElement.new(@driver)
    @loginpage = LoginPage.new(@driver)
    @eula = Eula.new(@driver)
    @landing = LandingPage.new(@driver)
    @roa = Roa.new(@driver)
    @leftnav = LeftSideNav.new(@driver)
    @lp = Launchpad.new(@driver)
    @commonTest = CommonTest.new(@driver)
    @modal = Modal.new(@driver)
    @lmAccd = LearnMoreAccd.new(@driver)


    @commonTest.passByLandingPageAndAuthenticate("zztest.patient01", "pass", "patient01, zztest", "D123401")

    @commonTest.waitForContentLoaded
    @leftnav.leftSideNav

    @leftnav.home_element.when_visible

    @leftnav.learnMore
    @commonElements.secondaryHeader_element.when_visible(timeout=10)


    @leftnav.kidneyInfo
    @commonElements.primaryHeader_element.when_visible(timeout=10)

    @leftnav.clickAccordion(1)
    sleep 0.5
  end


  after(:all) do
    @driver.close
  end


  dataSheetFilePath = File.dirname(__FILE__) + '/../../datasheet/Kidney_Info_Text_Content.xls'
  book = Spreadsheet.open dataSheetFilePath
  sheet1 = book.worksheet 'kidneyAndKidneyDisease'

  counter = 0
  sheet1.each 1 do |row|
  counter = counter + 1
  # if counter > 2
  #   break
  # end

    rowLength = row.length
    # puts "row[].length=" + row.length.to_s

    sectionID = row[0].to_i
    # puts "sectionID=" + sectionID.to_s
    expectedImageInfo = row[2].split(/\r?\n/)
    expectedImgName = expectedImageInfo.first
    expectedImgAcknowledgement = ""
    if expectedImageInfo.length > 1
      expectedImgAcknowledgement = expectedImageInfo.last
    end
    # puts "expectedImgName=" + expectedImgName
    expectedSectionHeader = row[3]
    # puts "expectedSectionHeader=" + expectedSectionHeader


      context 'Story#CKD-72~83|TC#CKD-766: Image and content for this section displays correctly - ' + expectedSectionHeader do

        if row[2] != "na"
          it '. Verify the image file name is correct: ' do
            if @lmAccd.getImgtUnderEachSection(sectionID, headingName).include?(expectedImgName) == false
              puts "Different! Failed sectionID=" + sectionID.to_s + "; Displayed Img=" + @lmAccd.getImgtUnderEachSection(sectionID, headingName)
            end
            expect(@lmAccd.getImgtUnderEachSection(sectionID, headingName).include?(expectedImgName)).to eq(true)

          end

          it '. Verify the image acknowledgement is correct: ' do
          expect(@lmAccd.getImgAcknowledgementUnderEachSection(sectionID, headingName)).to eq(expectedImgAcknowledgement)
        end

        it '. Click the image and verify it opens up in a modal screen. ' do
            if sectionID != 2
              @lmAccd.clickImgtUnderEachSection(sectionID, headingName)
              @modal.imgTitle_element.when_visible(timeout=10)
              expect(@modal.imgTitle).to eq(expectedSectionHeader)
              expect(@modal.closeImg?).to eq(true)
              @modal.closeImg
              @modal.imgTitle_element.when_not_visible
              expect(@modal.imgTitle?).to eq(false)
            end
          end

          it '. Verify that the segment header displays correctly. ' do
            $bodyContent = @lmAccd.getBodyContentUnderEachSection(sectionID, headingName)
            # puts "$bodyContent=" + $bodyContent
            expect($bodyContent.include?(expectedSectionHeader)).to eq(true)
          end

          it '. Verify the in Phone form factor, the image does not display' do

            #Reset to Phone size
            resizeWindowTo(320, 480)
            sleep 1
            expect(@lmAccd.isImgPresent(sectionID, headingName)).to eq(false)
            #Reset to the default size
            resizeWindowToDefault()

          end

          for column in 4..rowLength-1

            segmentName = "text Part " + (column-3).to_s
            expectedSegContent = row[column]
            # puts "expectedSegContent=" + expectedSegContent

            it '. Verify that all segments under this section displays correctly - ' + segmentName do
              $bodyContent = @lmAccd.getBodyContentUnderEachSection(sectionID, headingName)
              expect($bodyContent.include?(expectedSegContent)).to eq(true)

            end

          end

        else

          it '. Verify the Knowledge Check text displays ' do
            $bodyContent = @lmAccd.getBodyContentUnderEachSection(sectionID, headingName)
            # puts "$bodyContent=" + $bodyContent
            # puts "expectedSectionHeader=" + expectedSectionHeader
            expect($bodyContent.include?(expectedSectionHeader)).to eq(true)
          end

        end

       end

    end

  end

