#!/bin/env ruby
# encoding: utf-8

require 'rubygems'
require 'rspec'
require 'watir-webdriver'
require 'page-object'
require 'spreadsheet'

require_relative '../rspec_helper'
require_relative '../../lib/pages/login_page'
require_relative '../../lib/pages/eula'
require_relative '../../lib/pages/landing_page'
require_relative '../../lib/pages/roa'
require_relative '../../lib/pages/launchpad'
require_relative '../../lib/pages/common_elements'
require_relative '../../lib/pages/common_tests'
require_relative '../../lib/pages/modal_dialog'
require_relative '../../lib/pages/left_side_nav'
require_relative '../../lib/pages/learn_more_accordions'


describe 'Story#CKD-261 Kidney_Info_Learn_More_Content_CKD_261_spec.rb', :regression=>true do
  include DriverUtility

  idName = "kidney-info--learn-more-1"

  before(:all) do

    initializeConfigurations(BASE_URL)

    @commonElements = CommonElement.new(@driver)
    @loginpage = LoginPage.new(@driver)
    @eula = Eula.new(@driver)
    @landing = LandingPage.new(@driver)
    @roa = Roa.new(@driver)
    @leftnav = LeftSideNav.new(@driver)
    @lp = Launchpad.new(@driver)
    @commonTest = CommonTest.new(@driver)
    @modal = Modal.new(@driver)
    @lmAccd = LearnMoreAccd.new(@driver)


    @commonTest.passByLandingPageAndAuthenticate("zztest.patient01", "pass", "patient01, zztest", "D123401")

    @commonTest.waitForContentLoaded
    @leftnav.leftSideNav

    @commonTest.navigateToAsubFeature("LearnMore", ".kidney-info")

    #Expand the "Learn More" accordion
    @leftnav.clickAccordion(7)
    sleep 0.5
  end


  after(:all) do
    @driver.close
  end


  dataSheetFilePath = File.dirname(__FILE__) + '/../../datasheet/Learn_More_Content.xls'
  book = Spreadsheet.open dataSheetFilePath
  sheet1 = book.worksheet 'kidneyInfoLearnMore'

  counter = 0
  sheet1.each 1 do |row|
    counter = counter + 1
    #Below three lines are used to debug data-sheet row by row
    # if counter > 3
    #   break
    # end


    rowLength = row.length
    # puts "row[].length=" + row.length.to_s

    topicSeqID = row[0].to_i
    # puts "topicSeqID=" + topicSeqID.to_s
    expectedTopicTitle = row[2]
    # puts "expectedTopicTitle=" + expectedTopicTitle
    expectedHyperLink = row[3]
    # puts "expectedHyperLink=" + expectedHyperLink


    context 'Story#CKD-525|TC#CKD-835: Verify the Resource topic titile, hyper link display correctly. Clicking link opens the correct web page - ' + expectedTopicTitle  do

      if topicSeqID == 1 # Only need to verify this once
        it '. Verify that the text Resource displays ' do
          expect(@lmAccd.getResourceText(idName)).to eq("Resources")

        end
      end

      it '. Verify the resource title displays correctly: ' do

        expect(@lmAccd.getNthTopicTitle(idName, topicSeqID)).to eq(expectedTopicTitle)

      end

      it '. Verify that the resource topic has the correct hyper link. ' do

        expect(@lmAccd.getNthTopicHyperLink(idName, topicSeqID)).to eq(expectedHyperLink)
      end

      # if topicSeqID != 6
      #   it '. Click the topic and verify it opens up a page in the correct URL. ' do
      #
      #     @lmAccd.clickNthTopicHyperLink(idName, topicSeqID)
      #
      #     #switching to the New Window and verifying the title
      #     switchWindowToWindowHandleLast()
      #     if getCurrentURL().include?(expectedHyperLink.split("//")[1]) == false
      #       puts "Discrepancy! Displayed URL=" + getCurrentURL()
      #     end
      #     expect(getCurrentURL().include?(expectedHyperLink.split("//")[1])).to eq(true)
      #     @driver.driver.close()
      #
      #     #Switch back to the original app window
      #     switchWindowToWindowHandleFirst()
      #
      #   end
      # end

    end

  end

    context 'Story#CKD-525|TC#CKD-835: Verify the additional text a the bottom of the accordion displays correctly. ' do
      it '. Verify the *Link text displays correctly' do
        expect(@lmAccd.getAdditionalText(idName)).to eq("*Links will take you outside of the Department of Veterans Affairs website. VA does not endorse and is not responsible for the content of the linked websites.")
      end
    end

end

