#!/bin/env ruby
# encoding: utf-8

require 'rubygems'
require 'rspec'
require 'watir-webdriver'

require_relative '../rspec_helper'
require_relative '../../lib/pages/login_page'
require_relative '../../lib/pages/eula'
require_relative '../../lib/pages/landing_page'
require_relative '../../lib/pages/roa'
require_relative '../../lib/pages/right_side_nav'
require_relative '../../lib/pages/left_side_nav'
require_relative '../../lib/pages/launchpad'
require_relative '../../lib/pages/common_elements'
require_relative '../../lib/pages/common_tests'
require_relative '../../lib/module/DBUtility'

describe 'Story#CKD-1026 Learn_More_Feature_List_CKD_1026_spec.rb', :regression => true do
  include DriverUtility
  include DBUtility


  before(:all) do

    initializeConfigurations(BASE_URL)

    @commonElements = CommonElement.new(@driver)
    @commonTest = CommonTest.new(@driver)
    @loginpage = LoginPage.new(@driver)
    @eula = Eula.new(@driver)
    @landing = LandingPage.new(@driver)
    @roa = Roa.new(@driver)
    @rightnav = RightSideNav.new(@driver)
    @leftnav = LeftSideNav.new(@driver)
    @lp = Launchpad.new(@driver)

    @commonTest.passByLandingPageAndAuthenticate("zztest.patient01", "pass", "patient01, zztest", "D123401")

    @commonTest.waitForContentLoaded
    @leftnav.leftSideNav

    @leftnav.home_element.when_visible

    @leftnav.clickAppOptionName("LearnMore")

    @commonElements.secondaryHeader_element.when_visible(timeout=10)

  end

  after(:all) do
    @driver.close
  end

  context 'AC#CKD-1257|TC#CKD-1235: When the user selects the Learn More feature from the left panel navigation, the system displays the Feature groups in the Main Screen' do
    it '. Verify Page Header displays correctly' do
      expect(@commonElements.secondaryHeader).to eq("Learn More")
    end

    it '. Verify that features displayed have the correct name ' do
      expect(@leftnav.getSubFeatureText('.kidney-info', "LearnMore")).to eq("Kidney Info")
      expect(@leftnav.getSubFeatureText('.nutrition', "LearnMore")).to eq("Nutrition")
      expect(@leftnav.getSubFeatureText('.laboratory', "LearnMore")).to eq("Laboratory")
      expect(@leftnav.getSubFeatureText('.social-work-services', "LearnMore")).to eq("Social Work Services")
      expect(@leftnav.getSubFeatureText('.pharmacy', "LearnMore")).to eq("Pharmacy")
      expect(@leftnav.getSubFeatureText('.treatment', "LearnMore")).to eq("Treatment")
    end

    it '. Verify that feature names display in the right order' do
      expect(@leftnav.isThisFeatureInTheRightPlace(1, '.kidney-info', 'Kidney Info',"LearnMore")).to eq(true)
      expect(@leftnav.isThisFeatureInTheRightPlace(2, '.nutrition', 'Nutrition', "LearnMore")).to eq(true)
      expect(@leftnav.isThisFeatureInTheRightPlace(3, '.laboratory', 'Laboratory', "LearnMore")).to eq(true)
      expect(@leftnav.isThisFeatureInTheRightPlace(4, '.social-work-services', 'Social Work Services', "LearnMore")).to eq(true)
      expect(@leftnav.isThisFeatureInTheRightPlace(5, '.pharmacy', 'Pharmacy', "LearnMore")).to eq(true)
      expect(@leftnav.isThisFeatureInTheRightPlace(6, '.treatment', 'Treatment', "LearnMore")).to eq(true)

    end


  end

  context 'AC#CKD-1257|TC#CKD-1235:  In the tablet and desktop view the following instructional text is displayed in the Detail screen. Default text displays when no item is selected' do
    it '. Verify that the default text displays correctly' do
      expect(@commonElements.defaultTextToSelectItem).to eq("Select an item from the Learn More list to view details.")
    end

  end

end
