#!/bin/env ruby
# encoding: utf-8

require 'rspec'
require 'watir-webdriver'
require 'page-object'
require 'spreadsheet'

require_relative '../rspec_helper'
require_relative '../../lib/pages/login_page'
require_relative '../../lib/pages/common_elements'
require_relative '../../lib/pages/common_tests'
require_relative '../../lib/pages/left_side_nav'
require_relative '../../lib/pages/learn_more_accordions'

describe 'Story#CKD-1141 Learn_More_Introduction_CKD_1141_spec.rb', :regression=>true do
  include DriverUtility

  app_title = "MobileKidney"

  before(:all) do

    initializeConfigurations(BASE_URL)

    @commonElements = CommonElement.new(@driver)
    @loginpage = LoginPage.new(@driver)
    @leftnav = LeftSideNav.new(@driver)
    @commonTest = CommonTest.new(@driver)
    @learnMore = LearnMoreAccd.new(@driver)
    @commonTest.passByLandingPageAndAuthenticate("zztest.patient01", "pass", "patient01, zztest", "D123401")

  end

  after(:all) do
    @driver.close
  end

  dataSheetFilePath = File.dirname(__FILE__) + '/../../datasheet/Accordions_Test.xls'
  book = Spreadsheet.open dataSheetFilePath
  data = book.worksheet 'introduction'

  sections = [
    { :title => "Kidney Info", :selector => ".kidney-info" },
    { :title => "Nutrition", :selector => ".nutrition" },
    { :title => "Laboratory", :selector => ".laboratory" },
    { :title => "Social Work Services", :selector => ".social-work-services" },
    { :title => "Pharmacy", :selector => ".pharmacy" },
    { :title => "Treatment", :selector => ".treatment" }
  ]

  appOption = 'LearnMore'

  context 'AC #CKD-1366 | TC #CKD-1446 -- Learn More Introduction Content' do
    sections.each_with_index do |section, index|
      it ' . Verify introduction content for Learn More section - ' + section[:title] do
        offsetIndex = index + 1 # excel data index starts 1
        row = data.row(offsetIndex)

        @commonTest.navigateToAsubFeature(appOption, section[:selector])
        expect(@leftnav.getSubFeatureText(section[:selector], appOption)).to eq(section[:title])
        introElement = @learnMore.getLearnMoreSectionIntro
        expect(introElement.text).to eq(row[1])
      end
    end
  end

end
