#!/bin/env ruby
# encoding: utf-8

require 'rubygems'
require 'rspec'
require 'watir-webdriver'
require 'page-object'
require 'spreadsheet'

require_relative '../rspec_helper'
require_relative '../../lib/pages/login_page'
require_relative '../../lib/pages/eula'
require_relative '../../lib/pages/landing_page'
require_relative '../../lib/pages/roa'
require_relative '../../lib/pages/launchpad'
require_relative '../../lib/pages/common_elements'
require_relative '../../lib/pages/common_tests'
require_relative '../../lib/pages/modal_dialog'
require_relative '../../lib/pages/left_side_nav'



describe 'Story#CKD-22,258 Learn_More_Kidney_Info_Accordions_CKD_22_258_spec.rb', :regression=>true do
  include DriverUtility

  app_title = "MobileKidney"

  before(:all) do

    initializeConfigurations(BASE_URL)

    @commonElements = CommonElement.new(@driver)
    @loginpage = LoginPage.new(@driver)
    @eula = Eula.new(@driver)
    @landing = LandingPage.new(@driver)
    @roa = Roa.new(@driver)
    @leftnav = LeftSideNav.new(@driver)
    @lp = Launchpad.new(@driver)
    @commonTest = CommonTest.new(@driver)
    @modal = Modal.new(@driver)


    @commonTest.passByLandingPageAndAuthenticate("zztest.patient01", "pass", "patient01, zztest", "D123401")

  end


  after(:all) do
    @driver.close
  end

  dataSheetFilePath = File.dirname(__FILE__) + '/../../datasheet/Accordions_Test.xls'
  book = Spreadsheet.open dataSheetFilePath
  sheet1 = book.worksheet 'kidneyInfoAccordions'

  counter = 0
  preSubFeature = " "
  sheet1.each 1 do |row|
    counter = counter + 1
    # if counter > 8
    #   break
    # end

    # puts "row[1]=" + row[1]
    if row[1].include?("Return to") == false
      tempArry = row[1].split(">")

      navFirstStop = tempArry[0]
      # puts "navFirstStop=" + navFirstStop
      navSecondStop = tempArry[1]
      # puts "navSecondStop=" + navSecondStop
      navAccdSeq = tempArry[2].to_i
      # puts "navAccdSeq=" + navAccdSeq.to_s

      expectedAccdTitle = row[2]
      # puts "expectedAccdTitle=" + expectedAccdTitle

      context 'AC#CKD-53,259|TC#CKD-544,825: Accordion display for Kidney Info - ' + expectedAccdTitle do

        it '. Navigate to the right accordion, then verify the heading displays correctly.' do
          if navSecondStop != preSubFeature
            @commonTest.navigateToAsubFeature(navFirstStop, navSecondStop)
            preSubFeature = navSecondStop

          end

          expect(@leftnav.getAccordionTitle(navAccdSeq)).to eq(expectedAccdTitle)

          expect(@leftnav.getAccordionExpandedStatus(navAccdSeq)).to eq(false)

          expect(@leftnav.getAccordionAltText(navAccdSeq)).to eq("Expand")


        end

        it '. Click the accordion, verify the accordion is expanded and the alt text reads Collapse' do
          @leftnav.clickAccordion(navAccdSeq)
          expect(@leftnav.getAccordionExpandedStatus(navAccdSeq)).to eq(true)

          expect(@leftnav.getAccordionAltText(navAccdSeq)).to eq("Collapse")
          # @leftnav.clickAccordion(navAccdSeq)
          # sleep 0.5
        end

      end

      context 'AC#CKD-54,260|TC#CKD-544,825: Accordion Behavior - ' + expectedAccdTitle do
        it '. Verify that when expand an accordion, it automatically closes other accordions' do
          if expectedAccdTitle != "Learn More"
            #Open the next accordion
            newNum = navAccdSeq + 1
          else
            #Open the previous accordion
            newNum = navAccdSeq - 1
          end

          @leftnav.clickAccordion(newNum)
          sleep 0.5
          expect(@leftnav.getAccordionExpandedStatus(navAccdSeq)).to eq(false)

          expect(@leftnav.getAccordionAltText(navAccdSeq)).to eq("Expand")
          #Close the accordion that just got opened
          @leftnav.clickAccordion(newNum)
          sleep 0.5
        end

      end


    else
      altTextPreScreen = row[1]
      # puts "altTextPreScreen=" + altTextPreScreen

      context '  In Phone form factor, the > button is present and has the correct alt text ' do
        it '. Verify the in Phone form factor, the > button is present and has the correct alt text ' do
          if row[1].include?("Return to")

            #Reset to Phone size
            resizeWindowTo(320, 480)
            @commonElements.returnToPrevScreen_element.when_visible(timeout=10)
            expect(@commonElements.returnToPrevScreen?).to eq(true)
            expect(@commonElements.returnToPrevScreen_element.attribute("title")).to eq(altTextPreScreen)
            #Reset to the default size
            resizeWindowToDefault()
          end
        end
      end
    end

  end
end
