#!/bin/env ruby
# encoding: utf-8

require 'rubygems'
require 'rspec'
require 'watir-webdriver'

require_relative '../rspec_helper'
require_relative '../../lib/pages/left_side_nav'
require_relative '../../lib/pages/common_elements'
require_relative '../../lib/pages/common_tests'
require_relative '../../lib/pages/landing_page'
require_relative '../../lib/module/DBUtility'
require_relative '../../lib/module/MongoUtility'

describe 'Story#CKD-880, Landing_Notification_Count_CKD_880_spec.rb', :acceptance=>true do
  include DriverUtility
  include DBUtility
  include MongoUtility

  before(:all) do

    initializeConfigurations(BASE_URL)
    resetCollection("notificationPreferences", "notificationsdb", "spec/snapshots/notificationsdb/notificationPreferences.bson")
    resetCollection("preferences", "notificationsdb", "spec/snapshots/notificationsdb/preferences.bson")

    removeCollection("notifications", "notificationsdb")
    insertNotification("Your Medication Reminders goal is due on KIDNEY")
    insertNotification("Another reminder")
    insertNotification("Re: mind")
    insertNotification("Expired", Time.new(2000))

    @commonElements = CommonElement.new(@driver)
    @commonTest = CommonTest.new(@driver)
    @landing = LandingPage.new(@driver)

    @commonTest.passByLandingPageAndAuthenticate("zztest.patient13", "pass", "patient13, zztest", "PATID12")

    @commonTest.waitForContentLoaded
    @commonElements.contentLoaded_element.when_present(timeout=15)

  end

  after(:all) do
    @driver.close
  end

  context 'AC#CKD-1678|TC#CKD-1716: Notification Count-Display Unread Notifications' do
    it '. Verify the count displays' do
      # 3 because the 4th notification is past 30 days
      expect(@landing.unreadNotifications).to eq("3 Unread in last 30 days")
    end

    it ' with a bell icon' do
      expect(@landing.hasUnreadNotificationsIcon())
    end
  end

end

def insertNotification(body, createDate = Time.now)
  notification = {
    "patientIdentifier" => {
        "uniqueId" => "PATID12",
        "assigningAuthority" => "EDIPI"
    },
    "readFlag" => false,
    "source" => "MobileKidney - Kidney Trackers",
    "type" => "Mobile-Kidney",
    "timeZone" => "America/New_York"
  }
  notification["body"] = body
  notification["createDate"] = createDate
  notification["effectiveDisplayDate"] = Time.now
  insertDocument("notifications", "notificationsdb", notification)
end
