#!/bin/env ruby
# encoding: utf-8

require 'rubygems'
require 'rspec'
require 'watir-webdriver'

require_relative '../rspec_helper'
require_relative '../../lib/pages/left_side_nav'
require_relative '../../lib/pages/common_elements'
require_relative '../../lib/pages/common_tests'
require_relative '../../lib/pages/error_validations'
require_relative '../../lib/pages/notifications'
require_relative '../../lib/pages/modal_dialog'
require_relative '../../lib/pages/right_side_nav'
require_relative '../../lib/pages/user_guide'
require_relative '../../lib/module/DBUtility'
require_relative '../../lib/module/MongoUtility'

describe 'Story#CKD-876,879,1588 Notification_Settings_Initial_Screen_And_Gear_Icon_Screen_CKD_876_879_1588_spec.rb', :acceptance=>true do
  include DriverUtility
  include DBUtility
  include MongoUtility

  before(:all) do

    initializeConfigurations(BASE_URL)
    removeCollection("notifications", "notificationsdb")
    removeCollection("reminders", "remindersdb")
    removeCollection("notificationPreferences", "notificationsdb")
    removeCollection("preferences", "notificationsdb")

    @commonElements = CommonElement.new(@driver)
    @commonTest = CommonTest.new(@driver)
    @leftnav = LeftSideNav.new(@driver)
    @rightnav = RightSideNav.new(@driver)
    @userGuide = UserGuide.new(@driver)
    @error = Errors.new(@driver)
    @tklistDetail = TrackerListDetail.new(@driver)
    @notification = Notifications.new(@driver)
    @modal = Modal.new(@driver)

    @commonTest.justLogin("zztest.patient14", "pass", "patient14, zztest", "PATID13")
    @commonElements.contentLoaded_element.when_present(timeout=15)

    $todayLong = getDateNthDaysAgo(0, "%m/%d/%Y")
  end

  after(:all) do
    @driver.close
  end

    context 'Story#876|AC#CKD-1660|TC#CKD-1714: Notification display for first-time users ' do
      it '. Verify that the initial screen has the correct welcome text' do
        expect(@notification.modalHeader).to eq("Welcome zztest patient14")

      end

      it '. The instructional text display correctly' do
        expect(@notification.instruTextOnSettingS1).to eq("Notifications include reminder notices you create in this app, as well as Health Messages that may be sent to you by the Veteran's Administration. While you may adjust your notification delivery preferences for individual reminders, you must elect to receive Health Messages from the Veteran's Administration.")
        expect(@notification.instruTextOnSettingS2).to eq("As a first time user, please save your Notification Settings before using other app features. Note that notification settings apply to all VA health applications.")
        expect(@notification.learnMoreLink_element.text.strip).to eq("Learn more")
      end

      it '. Verify that clicking Learn More link opens up a new learn more page' do
        @notification.learnMoreLink
        switchWindowToWindowHandleLast()
        @userGuide.userGuideTitle_element.when_visible(timeout=10)
        expect(@userGuide.userGuideTitle).to eq("MobileKidney User Guide")
        switchWindowToWindowHandleFirst()
      end

      it '. Verify the Notification Setting, required field indicator, Email Address, Time Zone, OptIn all have the correct label' do
        expect(@notification.settingLabel).to eq("Notification Settings")
        expect(@notification.getRequiredFieldText("initialForm")).to eq("* required field")
        expect(@notification.emailLabel).to eq("Email Address:")
        expect(@notification.timeZoneLabel).to eq("Time Zone:")
        expect(@notification.optInLabel).to eq("Receive messages to help improve your health:")
      end

      it '. Verify that the Email field has 100 max character restriction and it display a correct instructional text' do
        expect(@tklistDetail.textareaMaxLengthTest(100, false, "input", "email")).to eq(1)
        expect(@notification.emailInstruTextOnInitSet).to eq("Your preferred email for notifications applies to all VA Health apps. You may modify this email under the Settings feature shown under Notifications.")
      end

      it '. Verify that the Time Zone field is required and set to Select as default and it throws a validation error when left not selected' do
        expect(@notification.timeZoneOnSettings).to eq("Select")
        @commonElements.saveBttn
        @error.errorHeader_element.when_visible
        errMsg = "Time Zone field is required."
        expect(@error.isThisErrorDisplayed(errMsg)).to eq(true)

      end

      it '. Verify that the Opt In options radio button is set to Yes as default' do
        expect(@notification.optIn_selected?).to eq("Yes")
      end
    end


    context 'AC#CKD-1661|TC#CKD-1714: Left side nav and Right side nav' do
      it '. Verify that when initial setting modal displays, the left side nav button is hidden; Right side nav only shows the About, Launchpad and Logout buttons' do
        expect(@leftnav.leftSideNav_element.attribute("class").include?("ng-hide")).to eq(true)
        @rightnav.userMenuBttn
        @rightnav.about_element.when_visible(timeout=10)
        expect(@rightnav.about?).to eq(true)
        expect(@rightnav.launchpad?).to eq(true)
        expect(@rightnav.logout?).to eq(true)
        sleep 1
        @rightnav.userMenuBttn
      end

    end

    context 'AC#CKD-1661|TC#CKD-1714: Notification Settings for Save Function' do
      it '. Provide email and set Time Zone, then save' do
        @notification.emailOnSetting= "test@test.com"
        sleep 0.3
        @notification.timeZoneOnSettings= "(-05:00) America/New_York (Eastern)"
        sleep 0.3
        @commonElements.saveBttn
        sleep 3 #give enough time for the result reflects in mongoDB

      end

      it '. Verify from mongoDB that the entries have been generated ' do
        expect(retrieveThisFieldInDocument("preferences", "notificationsdb", "EDIPI", "PATID13", "timeZone")).to eq("(-05:00) America/New_York (Eastern)")
        expect(retrieveThisFieldInDocument("preferences", "notificationsdb", "EDIPI", "PATID13", "emailAddress")).to eq("test@test.com")

      end

    end

    context 'Story#879|AC#CKD-1661|TC#CKD-1714: Gear Icon - Notification Setting Modal' do
      it '. Modal header, Instructional text display correctly' do
        @leftnav.leftSideNav
        @leftnav.home_element.when_visible

        @leftnav.clickAppOptionName("Notifications")
        @commonElements.contentLoaded_element.when_present(timeout=10)

        @notification.gearIcon
        @commonElements.contentLoaded_element.when_present(timeout=10)
        expect(@modal.modalTitle).to eq("Notification Settings")
        expect(@modal.section1).to eq("Manage your Notification preferences by adjusting the settings options below. Note that notification settings apply to all VA health applications.")

      end

      it '. Verify the Learn More link is present and clicking it directs to the Mobile Kidney User Guide' do
        expect(@notification.learnMoreLinkOnGear?).to eq(true)
        @notification.learnMoreLinkOnGear
        switchWindowToWindowHandleLast()
        @userGuide.userGuideTitle_element.when_visible(timeout=10)
        expect(@userGuide.userGuideTitle).to eq("MobileKidney User Guide")
        switchWindowToWindowHandleFirst()
      end

      it '. Verify the required field indicator is present; The email address, Time Zone and Opt In fields all carried the initial settings over. ' do
        expect(@notification.getRequiredFieldText("settingsForm")).to eq("* required field")
        expect(@notification.emailOnSetting).to eq("test@test.com")
        expect(@notification.timeZoneOnSettings).to eq("(-05:00) America/New_York (Eastern)")
        expect(@notification.optIn_selected?).to eq("Yes")
      end

      it '. Email has max 100 characters restriction. Instructional text displays correctly' do
        expect(@tklistDetail.textareaMaxLengthTest(100, false, "input", "email")).to eq(1)
        expect(@notification.emailInstruTextOnGearScreen).to eq("Your preferred email for notifications applies to all VA Health apps.")

      end

      it '. Click Cancel, it returns to the Notification List screen. Make a change, then Save, the change is updated to the mongoDB' do
        @commonElements.cancelBttn
        @commonElements.contentLoaded_element.when_present(timeout=10)
        expect(@commonElements.primaryHeader).to eq("Notifications")

        @notification.gearIcon
        @commonElements.contentLoaded_element.when_present(timeout=10)
        @notification.emailOnSetting= "newtest@test.com"
        sleep 0.3
        @commonElements.saveBttn
        @commonElements.contentLoaded_element.when_present(timeout=10)
        expect(@commonElements.primaryHeader).to eq("Notifications")

        expect(retrieveThisFieldInDocument("preferences", "notificationsdb", "EDIPI", "PATID13", "emailAddress")).to eq("newtest@test.com")

      end

    end

    context 'Story#1588|AC#CKD-1698|TC#CKD-1714: Gear Icon - Email notification error message' do
      it '. Create a notification from Kidney Tracker BP&P area with email delivery method' do
        @commonTest.navigateToAsubFeature("KidneyTrackers", ".blood-pressure-and-pulse")
        @commonElements.contentLoaded_element.when_present(timeout=10)
        @notification.notificationBttn
        @commonElements.contentLoaded_element.when_present(timeout=10)
        @notification.addANotification($todayLong, "Weekly", ["08:00 AM"], "Email")
        @commonElements.contentLoaded_element.when_present(timeout=15)
        expect(@notification.notificationBttnText).to eq("Notification (On)")

        expect(retrieveThisFieldInDocument("reminders", "remindersdb", "EDIPI", "PATID13", "notificationTypes")).to eq(["Email"])
      end

      it '. Remove the email from the setting page and then click Save. Verify a new modal displays with the correct header and the correct content' do
        @leftnav.leftSideNav
        @leftnav.home_element.when_visible
        @leftnav.clickAppOptionName("Notifications")
        @notification.gearIcon
        @commonElements.contentLoaded_element.when_present(timeout=10)
        @notification.emailOnSetting= ""
        sleep 0.3
        @commonElements.saveBttn
        Watir::Wait.until {@modal.warningModalTitle == "Warning"}
        expect(@modal.warningModalTitle).to eq("Warning")
        expect(@modal.section1OnWarning).to eq("An email address is required to receive email notifications. If you do not provide an email address any future email notifications will be cancelled.")
        expect(@modal.section2OnWarning).to eq("If you wish to continue saving, click SAVE, otherwise, select CANCEL to update your Notification Settings.")

      end

      it '. Click Cancel, Warning modal goes away, email stays, the Notification Settings screen resume; Click Save, all modals go away, reopen Gear Icon, verify that email is deleted. Confirm that the email entry in mongDB is removed too.' do
        @modal.ok2 #Click Cancel
        Watir::Wait.until {@modal.modalTitle == "Notification Settings"}
        expect(@modal.modalTitle).to eq("Notification Settings")
        expect(@notification.emailOnSetting).to eq("newtest@test.com")

        @notification.emailOnSetting= ""
        sleep 0.3
        @commonElements.saveBttn
        Watir::Wait.until {@modal.warningModalTitle == "Warning"}
        @modal.yes #Click Save
        @modal.modalTitle_element.when_not_visible(timeout=10)
        sleep 1
        expect(@modal.modalTitle?).to eq(false)

        @notification.gearIcon
        @commonElements.contentLoaded_element.when_present(timeout=10)
        expect(@notification.emailOnSetting).to eq("")

        expect(retrieveThisFieldInDocument("reminders", "remindersdb", "EDIPI", "PATID13", "notificationTypes")).to eq([])
      end
    end

end
