#!/bin/env ruby
# encoding: utf-8

require 'rubygems'
require 'rspec'
require 'watir-webdriver'

require_relative '../rspec_helper'
require_relative '../../lib/pages/left_side_nav'
require_relative '../../lib/pages/common_elements'
require_relative '../../lib/pages/common_tests'
require_relative '../../lib/pages/filters'
require_relative '../../lib/pages/error_validations'
require_relative '../../lib/pages/notifications'
require_relative '../../lib/pages/modal_dialog'
require_relative '../../lib/module/DBUtility'
require_relative '../../lib/module/MongoUtility'

describe 'Story#CKD-877 Notifications_All_Features_Filter_And_List_View_Delete_Notification_CKD_877_878_1756_spec.rb', :acceptance=>true do
  include DriverUtility
  include DBUtility
  include MongoUtility

  before(:all) do

    initializeConfigurations(BASE_URL)
    resetCollection("notificationPreferences", "notificationsdb", "spec/snapshots/notificationsdb/notificationPreferences.bson")
    resetCollection("preferences", "notificationsdb", "spec/snapshots/notificationsdb/preferences.bson")
    resetCollection("notifications", "notificationsdb", "spec/snapshots/notificationsdb/notifications.bson")

    @commonElements = CommonElement.new(@driver)
    @commonTest = CommonTest.new(@driver)
    @leftnav = LeftSideNav.new(@driver)
    @filter = Filters.new(@driver)
    @error = Errors.new(@driver)
    @tklistDetail = TrackerListDetail.new(@driver)
    @notification = Notifications.new(@driver)
    @modal = Modal.new(@driver)

    @commonTest.passByLandingPageAndAuthenticate("zztest.patient13", "pass", "patient13, zztest", "PATID12")

    @commonElements.angulartitle_element.when_visible
    @leftnav.leftSideNav
    @leftnav.home_element.when_visible

    @leftnav.clickAppOptionName("Notifications")
    @commonElements.secondaryHeader_element.when_visible(timeout=10)
    @commonElements.contentLoaded_element.when_present

    $todayLong = getDateNthDaysAgo(0, "%m/%d/%Y")
    $yesterdayLong = getDateNthDaysAgo(1, "%m/%d/%Y")
    $tomorrow = getDateNthDaysFromNow(1, "%m/%d/%Y")
    $sixYears1dayAgo = getDateNthDaysAgo(2192, "%m/%d/%Y")
    $oneYearAgo = getDateNthYearsAgo(1, "%m/%d/%Y")
    $thirtyDaysAgo = getDateNthDaysAgo(30, "%m/%d/%Y")
    $threeHundredDaysAgo = getDateNthDaysAgo(300, "%m/%d/%Y")

  end

  after(:all) do
    @driver.close
  end

  context 'AC#CKD-1669|TC#CKD-1684:  Notifications left panel navigation group options' do
    it '. Verify sub features Labels display correctly' do
      expect(@leftnav.getSubFeatureText('.all-notifications', 'Notifications')).to eq("All Notifications")
      expect(@leftnav.getSubFeatureText('.mobilekidney-app-notices', 'Notifications')).to eq("MobileKidney App Notices")
      expect(@leftnav.getSubFeatureText('.va-health-messages', 'Notifications')).to eq("VA Health Messages")
    end

    it '. Verify that all sub-features buttons display in the sub-feature list with the correct order' do
      expect(@leftnav.isThisFeatureInTheRightPlace(1, '.all-notifications', 'All Notifications','Notifications')).to eq(true)
      expect(@leftnav.isThisFeatureInTheRightPlace(2, '.mobilekidney-app-notices', 'MobileKidney App Notices','Notifications')).to eq(true)
      expect(@leftnav.isThisFeatureInTheRightPlace(3, '.va-health-messages', 'VA Health Messages','Notifications')).to eq(true)
    end

  end

  subFeaturesParam = [

      { :AC => 1670, :contextText => 'All Notifications', :featureName => 'All Notifications', :featureElementName => '.all-notifications' },
      { :AC => 1671, :contextText => 'MobileKidney In-App Notifications', :featureName => 'MobileKidney App Notices', :featureElementName => '.mobilekidney-app-notices' },
      { :AC => 1672, :contextText => 'VA Health Messages', :featureName => 'VA Health Messages', :featureElementName => '.va-health-messages' },

  ]

  subFeaturesParam.each do |feature|

    context 'AC#CKD-' + feature[:AC].to_s + '|TC#CKD-1684:  ' + feature[:contextText] do
      it '. Verify that the detail screen has the correct header' do
        @leftnav.clickSubFeatureName(feature[:featureElementName])
        @commonElements.contentLoaded_element.when_present(timeout=10)
        expect(@commonElements.primaryHeader).to eq(feature[:featureName])
      end

      it '. Filter defaults to an expanded view. Filter button alt text reads “Collapse filter options” when expanded.' do
        expect(@filter.startDate?).to eq(true)
        expect(@filter.filterAccdBttn_element.attribute('title')).to eq("Collapse filter options")
      end

      it '. Users can collapse the filter list by clicking on the Collapse filter icon. When collapsed, the filter icon alt text reads “Expand filter options.”' do
        @filter.filterAccdBttn
        @filter.startDate_element.when_not_visible(timeout=15)
        expect(@filter.filterAccdBttn_element.attribute('title')).to eq("Expand filter options")
      end

      it '. Date Range is default to the past 30 days' do
        @filter.filterAccdBttn
        @filter.startDate_element.when_visible(timeout=15)
        expect(@filter.startDate).to eq($thirtyDaysAgo)
        expect(@filter.endDate).to eq($todayLong)
      end

      it '. Verify Start Date and End Date label and the required field symbol display correctly ' do
        expect(@filter.getRequiredFieldSympolAndText("startDate")).to eq("*Start Date:")
        expect(@filter.getRequiredFieldSympolAndText("endDate")).to eq("*End Date:")
      end

      it '. Verify that the MM/DD/YYYY displays as the format sample' do
        expect(@filter.startDate_element.attribute('placeholder')).to eq("MM/DD/YYYY")
        expect(@filter.endDate_element.attribute('placeholder')).to eq("MM/DD/YYYY")
      end

      it '. Verify that the Start Date Cannot be future date, cannot be after the End date; date cannot be more than 1 year in the past' do
        @filter.startDate = ""
        @filter.startDate = $tomorrow
        sleep 0.5
        @filter.filterBttn
        @error.errorHeader_element.when_visible
        errMsg  = "Start Date must be between " + $oneYearAgo + " and " + $todayLong + "."
        expect(@error.isThisErrorDisplayed(errMsg)).to eq(true)
        expect(@error.isThisErrorDisplayed("Start Date must occur before End Date.")).to eq(true)

        @filter.startDate= $sixYears1dayAgo
        sleep 0.5
        @filter.filterBttn
        @error.errorHeader_element.when_visible
        #The front end prevents from typing in the dates outside of the past one year range. It truncates the last few digits
        errMsg = "Start Date must be formatted MM/DD/YYYY."
        expect(@error.isThisErrorDisplayed(errMsg)).to eq(true)
      end

      it '. Verify that the End Date Cannot be future date' do
        @filter.endDate = ""
        @filter.endDate = $tomorrow
        sleep 0.5
        @filter.filterBttn
        @error.errorHeader_element.when_visible
        errMsg  = "End Date must be between " + $oneYearAgo + " and " + $todayLong + "."
        expect(@error.isThisErrorDisplayed(errMsg)).to eq(true)

        @filter.startDate = ""
        @filter.endDate = ""
        @filter.startDate = $todayLong
        @filter.endDate = $yesterdayLong
        sleep 0.5
        @filter.filterBttn
        @error.errorHeader_element.when_visible
        expect(@error.isThisErrorDisplayed("Start Date must occur before End Date.")).to eq(true)
        #Click the Reset button to clear all the errors
        @filter.resetBttn
        @error.errorHeader_element.when_not_visible(timeout=10)
      end

    end

    context 'AC#CKD-' + feature[:AC].to_s + '|TC#CKD-1684:  ' + feature[:contextText] + '- Source field' do
      if feature[:AC] == 1670
        it '. Verify that Source drop down list has three choices; It is default to All Notifications' do
          expect(@notification.source).to eq("All Notifications")
          expect(@notification.source_options.include?("All Notifications")).to eq(true)
          expect(@notification.source_options.include?("MobileKidney App Notices")).to eq(true)
          expect(@notification.source_options.include?("VA Health Messages")).to eq(true)
        end
      elsif feature[:AC] == 1671 or feature[:AC] == 1672
        it '. In ' + feature[:contextText] + ', Verify that the Source drop down list is read only and default to ' + feature[:featureName] do
          expect(@notification.source).to eq(feature[:featureName])
          expect(@notification.source_element.attribute("disabled")).to eq("true")
        end
      end
    end

    context 'AC#CKD-' + feature[:AC].to_s + '|TC#CKD-1684:  ' + feature[:contextText] + '- Status radio button' do
      it '. Verify that the Status radio button has three choices and it is defaul to All' do
        expect(@notification.notificationStatus_selected?).to eq("All")
        expect(@notification.notificationStatus_values.include?("Unread")).to eq(true)
        expect(@notification.notificationStatus_values.include?("Read")).to eq(true)
      end

      if feature[:AC] == 1670
        it '. In ' + feature[:contextText] + 'Click All, Filter, and open one notification to read it; then Select Read radio button, and click Filter, returns the correct results' do
          @filter.startDate = $oneYearAgo;

          @notification.selectARadioButton("All", "statusOption")
          @filter.filterBttn
          @tklistDetail.summaryTable_element.when_visible(timeout=15)
          
          # Click to read one notification, cancel out of that screen
          @tklistDetail.clickAnEntryToEditOrDelete(1)
          @tklistDetail.cancelBttn
          @tklistDetail.summaryTable_element.when_visible(timeout=15)

          @notification.selectARadioButton("Read", "statusOption")
          @filter.filterBttn
          sleep 1
          expect(@notification.getTotalNotificationsCount()).to eq(1)
          @notification.selectARadioButton("Unread", "statusOption")
          @filter.filterBttn
          @commonTest.waitForContentLoaded
          expect(@notification.getTotalNotificationsCount()).to eq(2)
        end

        it 'Story#878|AC#1674|TC#1699: Verify that all information displays on Notification record detail screen are correct' do
          @notification.selectARadioButton("All", "statusOption")
          @filter.filterBttn
          @commonElements.contentLoaded_element.when_present(timeout=10)
          @tklistDetail.clickAnEntryToEditOrDelete(1)
          @commonElements.contentLoaded_element.when_present(timeout=10)
          expect(@commonElements.primaryHeader).to eq("View Notification")
          expect(@notification.notificationSource).to eq("MobileKidney - Kidney Trackers")
          expect(@notification.systemDateTime).to eq("02/04/2015 03:00 PM")
          expect(@notification.timeZone).to eq("America/New_York")
          expect(@notification.horizaonTalLine?).to eq(true)
          expect(@notification.notificationText).to eq("Dr. Smith")
          expect(@notification.cancelBttn?).to eq(true)
        end

        it 'Story#878|AC#1677|TC#1699: Verify that on Notification Record Detail screen the < icon is present and has the correct alt text; Click it returns to Notification List Screen' do
          expect(@commonElements.returnToPrevScreen?).to eq(true)
          expect(@commonElements.returnToPrevScreen_element.attribute("title")).to eq("Return to Previous Screen")
          @commonElements.returnToPrevScreen
          @commonElements.contentLoaded_element.when_present(timeout=10)
          expect(@commonElements.primaryHeader).to eq("All Notifications")
        end

      elsif feature[:AC] == 1671

        it '. In ' + feature[:contextText] + ' Select Read radio button, then click Filter, returns 1 record' do
          @filter.startDate = $oneYearAgo;
          @notification.selectARadioButton("Read", "statusOption")
          @filter.filterBttn
          @commonTest.waitForContentLoaded
          expect(@notification.getTotalNotificationsCount()).to eq(1)
          @notification.selectARadioButton("Unread", "statusOption")
          @filter.filterBttn
          @commonTest.waitForContentLoaded
          @tklistDetail.summaryTable_element.when_visible(timeout=15)
          expect(@notification.getTotalNotificationsCount()).to eq(1)
        end

      elsif feature[:AC] == 1672
        it '. In ' + feature[:contextText] + ' Select Read radio button, then click Filter, returns No result found' do
          @filter.startDate = $oneYearAgo;
          @notification.selectARadioButton("Read", "statusOption")
          @filter.filterBttn
          sleep 1
          @commonElements.noResultFountMsg_element.when_visible(timeout=10)
          expect(@commonElements.noResultFountMsg).to eq("No results found.")
          @notification.selectARadioButton("Unread", "statusOption")
          @filter.filterBttn
          sleep 1
          @tklistDetail.summaryTable_element.when_visible(timeout=15)
          expect(@notification.getTotalNotificationsCount()).to eq(1)

        end

      end

    end

    context 'AC#CKD-' + feature[:AC].to_s + '|TC#CKD-1684:  ' + feature[:contextText] + '- Data display in the table view' do
      it '. Verify that the data in the table view display accurately ' do

        # Switch to All
        @notification.selectARadioButton("All", "statusOption")
        @filter.filterBttn
        @commonElements.contentLoaded_element.when_visible

        test1 = ["Dr. Smith", "MobileKidney - Kidney Trackers", "02/04/2015 03:00 PM"]
        test2 = ["Your Medication Reminders goal is due on KIDNEY", "MobileKidney - Kidney Trackers", "02/04/2015 02:50 PM"]
        test3 = ["Test Reminder", "VA - Notifications", "02/04/2015 02:45 PM"]

        if feature[:AC] == 1670
          lists = [test1, test2, test3]
        elsif feature[:AC] == 1671
          lists = [test1, test2]
        elsif feature[:AC] == 1672
          lists = [test3]
        end

        lists.each_with_index do |listItem, i|
          if feature[:contextText] != 'All Notifications' then
            listItem.delete_at(1) # the Source column
          end
          expect(@notification.verifyNotificationRow(i+1, listItem)).to eq(true)
        end

      end

      it '. Verify that the data in the table display in the reverse chronological order ' do
        dateColumn = feature[:contextText] == 'All Notifications' ? 4 : 3
        expect(@tklistDetail.verifyListAreSortedReverseChronologically('%m/%d/%Y %I:%M %p', dateColumn, 'notifications')).to eq(true)
      end

      it '. Verify that < is shown on the list screen when on a phone view and the Status column is hidden' do
        # Reset to Phone size
        resizeWindowTo(320, 480)
        sleep 1
        expect(@commonElements.returnToPrevScreen?).to eq(true)
        expect(@commonElements.returnToPrevScreen_element.attribute('title')).to eq("Return to Notifications options")
        expect(@tklistDetail.isThisColumnHidden(1).include?("hidden-xs")).to eq(true) # Status column is hidden
        if feature[:contextText] == 'All Notifications' then
          expect(@tklistDetail.isThisColumnHidden(3).include?("hidden-xs")).to eq(true) # Source column is hidden if present
        end
      end

      it '. Verify clicking the < button returns to the Main Screen for the feature where the group options for that feature are listed.' do
        @commonElements.returnToPrevScreen
        @commonElements.secondaryHeader_element.when_visible(timeout=10)
        expect(@commonElements.secondaryHeader).to eq("Notifications")
        resizeWindowToDefault()
      end

    end

    context 'AC#CKD-' + feature[:AC].to_s + '|TC#CKD-1684:  ' + feature[:contextText] + '- The default No results found message' do
      it '. Verify if no records are found when a filter is applied the message the following message is shown in the screen area in place of the table view.' do
        @leftnav.clickSubFeatureName(feature[:featureElementName])
        @filter.startDate = $oneYearAgo
        @filter.endDate = $threeHundredDaysAgo
        sleep 1
        @filter.filterBttn
        @commonTest.waitForContentLoaded
        @commonElements.noResultFountMsg_element.when_visible
        expect(@commonElements.noResultFountMsg).to eq("No results found.")
      end
    end    

  end

  context 'Story #CKD-1756: Delete Notification' do
    it ' . Verify Delete button exists in Notification Detail view' do
      @leftnav.clickSubFeatureName(".all-notifications")
      @commonTest.waitForContentLoaded
      @filter.startDate = $oneYearAgo
      @filter.endDate = $todayLong
      @filter.filterBttn
      @commonTest.waitForContentLoaded
  
      expect(@notification.getTotalNotificationsCount()).to eq(3)

      @tklistDetail.clickAnEntryToEditOrDelete(1)
      @commonTest.waitForContentLoaded

      expect(@tklistDetail.deleteBttn?).to eq(true)
    end

    it '. Verify clicking Delete button opens up Confirmation modal' do
      @tklistDetail.deleteBttn
      @commonTest.waitForContentLoaded
      expect(@modal.modalTitle).to eq("Confirmation")
      expect(@modal.modalBody).to eq("Are you sure you want to remove this entry? Select YES to remove the entry or NO to return to the entry screen.")
      expect(@modal.ok2?).to eq(true)
      expect(@modal.yes?).to eq(true)
      expect(@modal.ok2_element.text).to eq("No")
      expect(@modal.yes_element.text).to eq("Yes")
    end

    it '. Verify clicking "No" on Confirmation modal returns user to entry screen' do
      @modal.ok2
      @commonTest.waitForContentLoaded
      expect(@commonElements.primaryHeader).to eq("View Notification")
    end

    it '. Verify cliicking "Yes" on Confirmation modal returns user to summary view with updated table view' do
      @tklistDetail.deleteBttn
      @commonTest.waitForContentLoaded
      @modal.yes
      @commonTest.waitForContentLoaded
      expect(@commonElements.primaryHeader).to eq("All Notifications")
      expect(@notification.getTotalNotificationsCount()).to eq(2)
    end

    it '. Verify deleted Notifcation is stored in database with deleted flag set' do
      docs = getDocumentByFields("notificationsdb", "notifications", {"deletedFlag" => true})
      expect(docs.length).to eq(1)
      doc = docs[0]
      expect(doc["deletedFlag"]).to eq(true)
    end

  end

end
