define(['angular', 'app', 'page_service', 'resourcedirectory_service'], function (angular, app) {
	"use strict";
	app.service('authenticationService',
		function ($http, $q, $window, $location, $rootScope, resourceDirectory, $injector, pageService) {
			var _auth = {},
				isAuthenticated;

			_auth.deleteCookie = function (cookieName) {
				document.cookie = encodeURIComponent(cookieName) + '=deleted; expires=' + new Date(0).toUTCString();
			};

			_auth.deleteToken = function () {
				var deferred = $q.defer();
				resourceDirectory.fetch().then(
					function (directory) {
						$http.delete(directory['token'])
							.success(function (response) {
								deferred.resolve(response);
							})
							.error(function (error) {
								deferred.reject(error);
							});
					}, function (error) {
						deferred.reject(error);
					});

				return deferred.promise;
			};

			_auth.wipeSessionData = function () {

				isAuthenticated = false;

				var deferred = $q.defer();
				var storedToken = sessionStorage.getItem('token'),
					currentToken = '';
				if (storedToken !== undefined && storedToken !== null) {
					currentToken = JSON.parse(storedToken);
					_auth.deleteToken(currentToken).finally(function () {
						sessionStorage.removeItem('token');
						$http.defaults.headers.common.Authorization = "";
						_auth.deleteCookie('JSESSIONID');
						deferred.resolve();
					});
				} else {
					deferred.resolve();
				}
				return deferred.promise;
			};

			_auth.gotoLoginWithRedirect = function (loginUrl) {
				_auth.wipeSessionData().then(function () {
					if(window.cordova) {
						window.open(loginUrl + "?" + new Date().getTime() + "&redirect_uri=mhpkidney://" + pageService.appUri, "_system");
					}
					else {
						window.open(loginUrl + "?" + new Date().getTime() + "&redirect_uri=" + pageService.appUri, "_self");
					}
				});
			};

			_auth.gotoLogoutWithRedirect = function (logoutUrl) {
				_auth.wipeSessionData().then(function () {
					if(window.cordova) {
						window.open(logoutUrl + "?" + new Date().getTime() + "&redirect_uri=mhpkidney://" + pageService.appUri, "_system");
                        location.reload();
                        navigator.app.exitApp();
					}
					else {
						window.open(logoutUrl + "?" + new Date().getTime() + "&redirect_uri=" + pageService.appUri, "_self");
					}
				});
			};

			_auth.logoutRedirectToLaunchpad = function () {
				resourceDirectory.fetch().then(
					function (directory) {
						var logoutUrl = directory['logout'];
						_auth.wipeSessionData().then(function () {
							if(window.cordova) {
								window.open(logoutUrl + "?" + new Date().getTime() + "&redirect_uri=mhplaunchPad://", "_system");
								location.reload();
                        		navigator.app.exitApp();
							}
							else{
								window.open(logoutUrl + "?" + new Date().getTime() + "&redirect_uri=" + pageService.appUri, "_self");
							}
						});
					}
				);
			};

			_auth.getCurrentToken = function () {
				_auth.setSessionTokenFromUrl();

				var storedToken = sessionStorage.getItem('token');
				if (storedToken !== undefined && storedToken !== 'undefined' && storedToken !== null && storedToken !== 'null') {
					return JSON.parse(storedToken);
				}
				return null;
			};

			_auth.setURLSessionToken = function(url){
				return url + (url.indexOf("?") === -1 ? "?" : "&") + "access_token=" + _auth.getCurrentToken();
			};

			_auth.setSessionTokenFromUrl = function () {
				var params = {},
					queryString = location.search.substring(1),
					regex = /(token)=([0-9a-zA-Z\-]*)/g,
					m,
					token;

				m = regex.exec(queryString);
				while (m) {
					params[decodeURIComponent(m[1])] = decodeURIComponent(m[2]);
					m = regex.exec(queryString);
				}

				token = params.token;
				_auth.setSessionToken(token);
			};

			_auth.setSessionToken = function (token) {
				if (token !== undefined && token !== 'undefined' && token !== null && token !== 'null') {
					sessionStorage.setItem('token', JSON.stringify(token));
				}
			};

			_auth.setAuthorizationRequestHeader = function (currentToken) {
				$http.defaults.headers.common.Authorization = "Bearer " + currentToken;
			};

			_auth.validateToken = function () {

				var deferred = $q.defer();

				var currentToken = _auth.getCurrentToken();

				resourceDirectory.fetch().then(
					function (directory) {
						// $http.post(directory['validate-token'], {'token': token}).then(
						_auth.setAuthorizationRequestHeader(currentToken);
						$http.get(directory['mhpuser']).then(function (response) {
							deferred.resolve(response);
						}, function (error) {
							deferred.resolve(error);
						});
					},
					function (error) {
						deferred.reject(error);
					}
				);

				return deferred.promise;
			};

			_auth.authorize = function () {

				resourceDirectory.fetch().then(function (directory) {
					var loginUrl = directory['oauth-login'];
					_auth.gotoLoginWithRedirect(loginUrl);
				});
			};

			_auth.authenticate = function () {

				var deferred = $q.defer();

				_auth.checkAuthStatus().then(function (authStatus) {
					if (authStatus) {
						$injector.invoke(['connectionTimeoutService', function (connectionTimeoutService) {
							connectionTimeoutService.run();
						}]);
						deferred.resolve(authStatus);
					} else {
						if (window.cordova) {
							/*nativeAuth.authorize(
								function (token) {
									_auth.setSessionToken(token);
									window.location.reload();
								},
								function () {
									deferred.reject(authStatus);
								});
						} else {*/
							_auth.authorize();
							deferred.reject(authStatus);
						}
					}
				});

				return deferred.promise;
			};

			_auth.isAuthenticated = function () {
				return isAuthenticated;
			};

			_auth.checkAuthStatus = function () {

				var deferred = $q.defer();

				_auth.validateToken().then(function (response) {
					isAuthenticated = (response.status === 200);
					$injector.invoke(['connectionTimeoutService' ,function (connectionTimeoutService) {
						connectionTimeoutService.run();
					}]);
					deferred.resolve(isAuthenticated);
				}, function () {
					isAuthenticated = false;
					deferred.resolve(isAuthenticated);
				});

				return deferred.promise;
			};

			_auth.isAuthenticatedPromise = function () {
				var defer = $q.defer();

				_auth.checkAuthStatus().then(function (status) {
					status ? defer.resolve() : defer.reject();
				});

				return defer.promise;
			};

			return _auth;
		});
});