define(['angular', 'app'], function(angular, app) {
	app.constant('LearnMoreConstants', {
		'kidney-info': {
			introduction: 'When you have chronic kidney disease, you have a new job—to take care of yourself and your kidneys. Learn about steps you can take to stay as healthy as possible.',
			sections: [
				{
					title: 'Kidneys and Kidney Disease',
					id: 'kidney-info--disease',
					templateUrl: 'src/modules/learn-more/pages/kidney-info/kidneys-and-disease.html',
					quizUrl: 'src/modules/learn-more/pages/kidney-info/kidneys-and-disease_quiz.json'
				},
				{
					title: 'Symptoms of Kidney Disease',
					id: 'kidney-info--symptoms',
					templateUrl: 'src/modules/learn-more/pages/kidney-info/symptoms.html',
					quizUrl: 'src/modules/learn-more/pages/kidney-info/symptoms_quiz.json'
				},
				{
					title: 'How to Protect Your Kidneys',
					id: 'kidney-info--protect',
					templateUrl: 'src/modules/learn-more/pages/kidney-info/protect.html',
					quizUrl: 'src/modules/learn-more/pages/kidney-info/protect_quiz.json'
				},
				{
					title: 'How to Slow Kidney Disease: When You Have Diabetes',
					id: 'kidney-info--slow-diabetes',
					templateUrl: 'src/modules/learn-more/pages/kidney-info/slow-diabetes.html',
					quizUrl: 'src/modules/learn-more/pages/kidney-info/slow-diabetes_quiz.json'
				},
				{
					title: 'How to Slow Kidney Disease: When You Have High Blood Pressure',
					id: 'kidney-info--slow-high-bp',
					templateUrl: 'src/modules/learn-more/pages/kidney-info/slow-high-bp.html',
					quizUrl: 'src/modules/learn-more/pages/kidney-info/slow-high-bp_quiz.json'
				},
				{
					title: 'Your Role in Your Kidney Care',
					id: 'kidney-info--your-role',
					templateUrl: 'src/modules/learn-more/pages/kidney-info/role.html',
					quizUrl: 'src/modules/learn-more/pages/kidney-info/role_quiz.json'
				},
				{
					title: 'Learn More',
					id: 'kidney-info--learn-more',
					templateUrl: 'src/modules/learn-more/pages/kidney-info/learn-more.html'
				}
			]
		},
		'nutrition': {
			introduction: 'When your kidneys don’t work well, some foods are better choices than others. Here in the <strong>Nutrition</strong> room, you can learn about key nutrients, like protein, potassium, and sodium. Find out how to use them to improve your health. Choose any topic from the list below to learn more.',
			sections: [
				{
					title: 'Get the Right Amount of Protein',
					id: 'nutrition--protein',
					templateUrl: 'src/modules/learn-more/pages/nutrition/protein.html',
					quizUrl: 'src/modules/learn-more/pages/nutrition/protein_quiz.json'
				},
				{
					title: 'How and Why to Limit Phosphorus',
					id: 'nutrition--phosphorus',
					templateUrl: 'src/modules/learn-more/pages/nutrition/phosphorus.html',
					quizUrl: 'src/modules/learn-more/pages/nutrition/phosphorus_quiz.json'
				},
				{
					title: 'Manage Your Potassium',
					id: 'nutrition--potassium',
					templateUrl: 'src/modules/learn-more/pages/nutrition/potassium.html',
					quizUrl: 'src/modules/learn-more/pages/nutrition/potassium_quiz.json'
				},
				{
					title: 'Pay Attention to Your Sodium and Fluid',
					id: 'nutrition--sodium',
					templateUrl: 'src/modules/learn-more/pages/nutrition/sodium.html',
					quizUrl: 'src/modules/learn-more/pages/nutrition/sodium_quiz.json'
				},
				{
					title: 'Learn More',
					id: 'nutrition--learn-more',
					templateUrl: 'src/modules/learn-more/pages/nutrition/learn-more.html'
				}
			]
		},
		'laboratory': {
			introduction: 'Some people with chronic kidney disease don’t feel any symptoms. Lab tests can show what is really going on with your kidneys. In the <strong>Laboratory</strong>, you can learn about common blood and urine tests that check kidney health and how to use them to track your progress. Choose any topic from the list below to learn more.',
			sections: [
				{
					title: 'Understand Your Kidney Lab Tests',
					id: 'laboratory--understand',
					templateUrl: 'src/modules/learn-more/pages/laboratory/understand.html',
					quizUrl: 'src/modules/learn-more/pages/laboratory/understand_quiz.json'
				},
				{
					title: 'Creatinine and eGFR',
					id: 'laboratory--creatinine',
					templateUrl: 'src/modules/learn-more/pages/laboratory/creatinine.html',
					quizUrl: 'src/modules/learn-more/pages/laboratory/creatinine_quiz.json'
				},
				{
					title: 'Your Calcium and Phosphorus Levels',
					id: 'laboratory--calcium-phosphorus',
					templateUrl: 'src/modules/learn-more/pages/laboratory/calcium-phosphorus.html',
					quizUrl: 'src/modules/learn-more/pages/laboratory/calcium-phosphorus_quiz.json'
				},
				{
					title: 'Your Potassium Level',
					id: 'laboratory--potassium',
					templateUrl: 'src/modules/learn-more/pages/laboratory/potassium.html',
					quizUrl: 'src/modules/learn-more/pages/laboratory/potassium_quiz.json'
				},
				{
					title: 'What You Need to Know About Hemoglobin',
					id: 'laboratory--hemoglobin',
					templateUrl: 'src/modules/learn-more/pages/laboratory/hemoglobin.html',
					quizUrl: 'src/modules/learn-more/pages/laboratory/hemoglobin_quiz.json'
				},
				{
					title: 'Measuring Albumin',
					id: 'laboratory--albumin',
					templateUrl: 'src/modules/learn-more/pages/laboratory/albumin.html',
					quizUrl: 'src/modules/learn-more/pages/laboratory/albumin_quiz.json'
				},
				{
					title: 'Your Hemoglobin A1c Level',
					id: 'laboratory--hemoglobin-a1c',
					templateUrl: 'src/modules/learn-more/pages/laboratory/hemoglobin-a1c.html',
					quizUrl: 'src/modules/learn-more/pages/laboratory/hemoglobin-a1c_quiz.json'
				},
				{
					title: 'Learn More',
					id: 'laboratory--learn-more',
					templateUrl: 'src/modules/learn-more/pages/laboratory/learn-more.html'
				}
			]
		},
		'social-work-services': {
			introduction: 'Your VA social worker can help you learn to cope with kidney disease and how it affects your life. He or she will help you get the VA and other care you are entitled to. Choose any topic from the list below to learn more.',
			sections: [
				{
					title: 'Coping with Your Feelings',
					id: 'social-work-services--coping',
					templateUrl: 'src/modules/learn-more/pages/social-work-services/coping.html',
					quizUrl: 'src/modules/learn-more/pages/social-work-services/coping_quiz.json'
				},
				{
					title: 'Your Lifestyle',
					id: 'social-work-services--lifestyle',
					templateUrl: 'src/modules/learn-more/pages/social-work-services/lifestyle.html',
					quizUrl: 'src/modules/learn-more/pages/social-work-services/lifestyle_quiz.json'
				},
				{
					title: 'Paying for Kidney Disease Treatment',
					id: 'social-work-services--paying',
					templateUrl: 'src/modules/learn-more/pages/social-work-services/paying.html',
					quizUrl: 'src/modules/learn-more/pages/social-work-services/paying_quiz.json'
				},
				{
					title: 'Advance Directives',
					id: 'social-work-services--advance-directive',
					templateUrl: 'src/modules/learn-more/pages/social-work-services/advance-directive.html',
					quizUrl: 'src/modules/learn-more/pages/social-work-services/advance-directive_quiz.json'
				},
				{
					title: 'Learn More',
					id: 'social-work-services--learn-more',
					templateUrl: 'src/modules/learn-more/pages/social-work-services/learn-more.html'
				}
			]
		},
		'pharmacy': {
			introduction: 'Medicines are a key part of treatment for chronic kidney disease. They can help you feel better and help you avoid complications. Here in the <strong>Pharmacy</strong>, you can learn about the medicines your doctor may prescribe. Choose any topic from the list below to learn more.',
			sections: [
				{
					title: 'Taking Prescribed and OTC Medications',
					id: 'pharmacy--medications',
					templateUrl: 'src/modules/learn-more/pages/pharmacy/medications.html',
					quizUrl: 'src/modules/learn-more/pages/pharmacy/medications_quiz.json'
				},
				{
					title: 'Blood Pressure Medicines',
					id: 'pharmacy--blood-pressure',
					templateUrl: 'src/modules/learn-more/pages/pharmacy/blood-pressure.html',
					quizUrl: 'src/modules/learn-more/pages/pharmacy/blood-pressure_quiz.json'
				},
				{
					title: 'Medicines to Prevent Bone Disease',
					id: 'pharmacy--bone-disease',
					templateUrl: 'src/modules/learn-more/pages/pharmacy/bone-disease.html',
					quizUrl: 'src/modules/learn-more/pages/pharmacy/bone-disease_quiz.json'
				},
				{
					title: 'Iron and EPO for Anemia',
					id: 'pharmacy--anemia',
					templateUrl: 'src/modules/learn-more/pages/pharmacy/anemia.html',
					quizUrl: 'src/modules/learn-more/pages/pharmacy/anemia_quiz.json'
				},
				{
					title: 'Phosphate Binders',
					id: 'pharmacy--phosphate',
					templateUrl: 'src/modules/learn-more/pages/pharmacy/phosphate.html',
					quizUrl: 'src/modules/learn-more/pages/pharmacy/phosphate_quiz.json'
				},
				{
					title: 'Diabetes Medicines and Kidney Disease',
					id: 'pharmacy--diabetes',
					templateUrl: 'src/modules/learn-more/pages/pharmacy/diabetes.html',
					quizUrl: 'src/modules/learn-more/pages/pharmacy/diabetes_quiz.json'
				},
				{
					title: 'Cholesterol Medicines',
					id: 'pharmacy--cholesterol',
					templateUrl: 'src/modules/learn-more/pages/pharmacy/cholesterol.html',
					quizUrl: 'src/modules/learn-more/pages/pharmacy/cholesterol_quiz.json'
				},
				{
					title: 'Pain Medicines and Kidney Disease',
					id: 'pharmacy--pain',
					templateUrl: 'src/modules/learn-more/pages/pharmacy/pain.html',
					quizUrl: 'src/modules/learn-more/pages/pharmacy/pain_quiz.json'
				},
				{
					title: 'Learn More',
					id: 'pharmacy--learn-more',
					templateUrl: 'src/modules/learn-more/pages/pharmacy/learn-more.html'
				}
			]
		},
		'treatment': {
			introduction: 'If your kidneys fail, the treatment you choose will affect every part of your life. The <strong>Treatment</strong> room can help you make a choice that is a good fit for the way you want to live. Choose any topic from the list below to learn more.',
			sections: [
				{
					title: 'If Your Kidneys Fail',
					id: 'treatment--fail',
					templateUrl: 'src/modules/learn-more/pages/treatment/fail.html',
					quizUrl: 'src/modules/learn-more/pages/treatment/fail_quiz.json'
				},
				{
					title: 'Peritoneal Dialysis and Your Lifestyle',
					id: 'treatment--dialysis',
					templateUrl: 'src/modules/learn-more/pages/treatment/dialysis.html',
					quizUrl: 'src/modules/learn-more/pages/treatment/dialysis_quiz.json'
				},
				{
					title: 'Hemodialysis in a Clinic and Your Lifestyle',
					id: 'treatment--hemodialysis-clinic',
					templateUrl: 'src/modules/learn-more/pages/treatment/hemodialysis-clinic.html',
					quizUrl: 'src/modules/learn-more/pages/treatment/hemodialysis-clinic_quiz.json'
				},
				{
					title: 'Hemodialysis at Home and Your Lifestyle',
					id: 'treatment--hemodialysis-home',
					templateUrl: 'src/modules/learn-more/pages/treatment/hemodialysis-home.html',
					quizUrl: 'src/modules/learn-more/pages/treatment/hemodialysis-home_quiz.json'
				},
				{
					title: 'Kidney Transplant and Your Lifestyle',
					id: 'treatment--transplant',
					templateUrl: 'src/modules/learn-more/pages/treatment/transplant.html',
					quizUrl: 'src/modules/learn-more/pages/treatment/transplant_quiz.json'
				},
				{
					title: 'Medical Care without Dialysis',
					id: 'treatment--no-dialysis',
					templateUrl: 'src/modules/learn-more/pages/treatment/no-dialysis.html',
					quizUrl: 'src/modules/learn-more/pages/treatment/no-dialysis_quiz.json'
				},
				{
					title: 'Learn More',
					id: 'treatment--learn-more',
					templateUrl: 'src/modules/learn-more/pages/treatment/learn-more.html'
				}
			]
		}
	});
});