define(['angular', 'app'], function (angular, app) {
	"use strict";

	app.service('KnowledgeCheckService', function () {
		var knowledgeCheckService = {
			/**
			 * Return whether all questions in the given quiz array have their 'selectedOption' member set.
			 */
			isQuizComplete: function(quiz) {
				for (var i = 0; i < quiz.length; i++) {
					var question = quiz[i];
					if (isNaN(Number(question.selectedOption)))
						return false;
				}
				return true;
			},

			/**
			 * Check a quiz array, setting the 'correct' member of each question.
			 * Returns an array of questions that were incorrect, or an empty array for a perfect quiz.
			 */
			checkQuiz: function(quiz) {
				var incorrect = [];
				for (var i = 0; i < quiz.length; i++) {
					var question = quiz[i];
					question.correct = question.selectedOption == question.correctOption;
					if (!question.correct)
						incorrect.push(i);
				}
				return incorrect;
			}
		}

		return knowledgeCheckService;
	});
});