define(['KnowledgeCheckService'], function() {
	'use strict';

	describe("The knowledge check service", function (){
		var service,
			quiz;

		var completeQuiz = function() {
			quiz.forEach(function(question) {
				question.selectedOption = 1;
			});
		}

		beforeEach( function () {
			module('angularTemplateApp');

			inject(function(KnowledgeCheckService) {
				service = KnowledgeCheckService;
			});

			quiz = [
				{
					question: 'Kidneys are located:',
					options: [
						'In the front of the body, just above the waist',
						'In the back of the body, just above the waist',
						'In the front of the body, just below the waist',
						'In the back of the body, just below the waist'
					],
					correctOption: 1,
					answer: 'Many people think that the kidneys are below the waist, but they are above it, protected by the rib cage.'
				},
				{
					question: 'Chronic kidney disease is:',
					options: [
						'A slow, permanent loss of function due to disease, with five stages',
						'A sudden shut down of the kidneys due to loss of blood or a toxin'
					],
					correctOption: 0,
					answer: 'Often, people don’t know they have a kidney problem, because they may feel good until the kidneys are very damaged.'
				}
			];
		});

		it ("should report an incomplete quiz by default", function() {
			expect(service.isQuizComplete(quiz)).toBe(false);
		});

		it ("should report a complete quiz", function() {
			completeQuiz();
			expect(service.isQuizComplete(quiz)).toBe(true);
		});

		it ("should check a quiz", function() {
			completeQuiz();

			var incorrect = service.checkQuiz(quiz);
			quiz.forEach(function(question) {
				expect(question.correct).toBeDefined();
			});

			expect(incorrect.length).toBeGreaterThan(0);
			incorrect.forEach(function(index) {
				expect(quiz[index].correct).toBe(false);
			});
		});
	});
});