define(["angular", "app", "KnowledgeCheckService"], function (angular, app) {
	"use strict";

	app.directive('knowledgeCheck', function () {
		return {
			restrict: 'A',
			transclude: true,
			scope: {
				id: '@',
				quiz: '=quiz'
			},
			controller: function ($scope, $modal, KnowledgeCheckService, focusService) {

				var quiz = $scope.quiz;
				var id = $scope.id;

				$scope.openQuiz = function() {
					var modalInstance = $modal.open({
						windowTemplateUrl: 'src/ui-components/modals/helper/modal-window_template.html',
						templateUrl: 'src/modules/learn-more/knowledge-check/directives/knowledge-check-quiz_template.html',
						controller: function($scope, $modalInstance) {
							$scope.quiz = angular.copy(quiz);
							$scope.originalQuiz = angular.copy(quiz);
							$scope.id = id;

							$scope.closeQuiz = function() {
								$modalInstance.close();
							};

							$scope.isCheckQuizDisabled = function() {
								return angular.equals($scope.quiz, $scope.originalQuiz) || !KnowledgeCheckService.isQuizComplete($scope.quiz);
							}

							$scope.checkQuiz = function() {
								$scope.incorrect = KnowledgeCheckService.checkQuiz($scope.quiz);
								$scope.originalQuiz = angular.copy($scope.quiz);

								if ($scope.incorrect.length)
									focusService.focusElement($('div.knowledge-check-incorrect'));
							};
						}
					});

					modalInstance.result.finally(function () {
						focusService.focusElement(angular.element('button[id=' + item.id + ']'));
					});

					$scope.$watch(function () {
						return $('div.modal-header h3').is(":visible");
					}, function (isVisible, wasVisible) {
						if (isVisible && !wasVisible)
			                focusService.focusElement($('div.modal-header h3'));
					});
				}
			},
			link: function($scope, element, attrs, controller, transclude) {
				element.on('click', $scope.openQuiz);
				element.attr('disabled', 'disabled');
				transclude($scope, function(clone) {
                    element.append(clone);
                });
			}
		};
	});
});