define(['GraphService'], function () {
	'use strict';

	describe('Graph Service - glucose', function () {
		var service,
            sectionMock = 'glucose',
            filterMock = {
                startDate: '11/01/2014 12:00 AM',
                endDate: '12/01/2014 11:59 PM'
            },
            listMock = [{
                    recorded: '11/11/2014 8:00 PM',
                    method: 'Fasting (8 hours)',
                    valueQuantity: {
                        value: 50
                    }
                },
                {
                    recorded: '11/30/2014 6:55 PM',
                    method: 'After Meal',
                    valueQuantity: {
                        value: 300
                    }
                },
                {
                    recorded: '11/22/2014 7:25 PM',
                    method: 'After Meal',
                    valueQuantity: {
                        value: 'High'
                    }
                },
                {
                    recorded: '11/21/2014 2:30 PM',
                    method: 'Unknown',
                    valueQuantity: {
                        value: 0
                    }
                }
            ],
            metaDataMock = [{
                label : 'Glucose Level',
                units : 'mg/dl',
                min : '0',
                max : '400'
            }];

		beforeEach(function() {
			module('angularTemplateApp');

            module(function($provide) {
                $provide.value('TrackersConstants', {
                    glucose: {
                        entry: {
                            testConditions: ["Fasting (8 hours)", "After Meal", "Unknown"]
                        }
                    }
                });
            });

			inject(function(GraphService) {
				service = GraphService;
			});
		});

        describe('methods - glucose', function() {
            it('should filter graph points, and get the x & y axis config options', function() {
                var entry = function(day, hours, minutes, index) {
                    return {
                        x: Date.UTC(2014, 10, day, hours, minutes),
                        y: listMock[index].valueQuantity.value,
                        method: listMock[index].method
                    };
                }
                var entry1 = entry(11, 20, 0, 0);
                var entry2 = entry(30, 18, 55, 1);
                var entry3 = entry(21, 14, 30, 3);

                var output = service.getGraphConfig(sectionMock, filterMock, listMock, metaDataMock);

                expect(output.series.length).toEqual(4);

                expect(output.series[0].name).toEqual('connecting-line');
                expect(output.series[0].marker).toEqual({ radius: 1 });
                expect(output.series[0].data).toEqual([ entry3, entry2, entry1 ]);

                expect(output.series[1].name).toEqual('Fasting (8 hours)');
                expect(output.series[1].marker).toEqual({ radius: 6 });
                expect(output.series[1].data).toEqual([ entry1 ]);

                expect(output.series[2].name).toEqual('After Meal');
                expect(output.series[2].marker).toEqual({ radius: 6 });
                expect(output.series[2].data).toEqual([ entry2 ]);

                expect(output.series[3].name).toEqual('Unknown');
                expect(output.series[3].marker).toEqual({ radius: 6 });
                expect(output.series[3].data).toEqual([ entry3 ]);

                expect(output.xAxis).toEqual({
                    type: 'datetime',
                    dateTimeLabelFormats: {
                        millisecond: '%b %e %I:%M %p',
                        second: '%b %e %I:%M %p',
                        minute: '%b %e %I:%M %p',
                        hour: '%b %e %I:%M %p',
                        day: '%b %e',
                        week: '%b %e',
                        month: '%b %Y',
                        year: '%Y'
                    },
                    minRange: 24 * 3600000,
                    minTickInterval: 3600000,
                    min: Date.UTC(2014, 10, 1, 0, 0),
                    max: Date.UTC(2014, 11, 2, 0, 0),
                    title: { text: 'Date/Time' }
                });
            });
        });
	});
});