define(['angular', 'app'], function (angular, app) {
    "use strict";
    app.service('TrackersRemindersService', function ($q, TrackersRemindersInstanceService, $state, $filter) {

        var TrackersRemindersService = {},
            remindersService,
            key,
            section;

        TrackersRemindersService.init = function(instanceKey) {
            remindersService = TrackersRemindersInstanceService.instance(instanceKey + "-reminders");
            key = instanceKey;
            section = $filter('filter')($state.current.data.paramSections, { paramValue: key }, true)[0].sectionName;
        };

        TrackersRemindersService.getReminder = function(name) {
            var defer = $q.defer();

            remindersService.fetch().then(function(response) {
                if(response.size === 0) {
                    defer.resolve(remindersService.createEmpty());
                } else {
                    defer.resolve(response.reminders[0]);
                }
            }, function(error) {
                defer.reject(error);
            });

            return defer.promise;
        };

        TrackersRemindersService.save = function(reminder) {
            reminder.title = "Update your " + section + " Tracker now.";
            if (reminder.notificationStatus == "On") {
                reminder.healthTrackerId = key;
                reminder.emailSignature = "MobileKidney - Kidney Trackers";
                reminder.auxData = createReminderAuxData();
            }

            var defer = $q.defer();

            remindersService.save(reminder).then(function() {
                defer.resolve();
            }, function(error){
                defer.reject(error);
            });

            return defer.promise;
        };

        function createReminderAuxData() {
            var subject = "Update your " + section + " Tracker now.";

            var body = "<br/>This notice is provided to help you remember to update your " + section + " Tracker.<br/><br/>";

            var updateMsg = "Update this Kidney Trackers entry in the <appLink><br/><br/>" +
                "To stop future notices, edit the notification settings inside the Kidney Trackers feature within the MobileKidney App.";

            return [
                {key: "emailSubject", value: subject},
                {key: "emailBody", value: body},
                {key: "emailUpdateMessage", value: updateMsg},
                {key: "emailSignature", value: "MobileKidney - Kidney Trackers"},
                {key: "source", value: "KIDNEY"},
                {key: "appName", value: "MobileKidney"},
                {key: "appUri", value: 'mobile-kidney'}
            ];
        };

        return TrackersRemindersService;
    });
});
