define(['angular', 'app'], function (angular, app) {
	'use strict';

	app.constant('TrackersServiceConstants', {
		'glucose': {
			extensions: {
				object: {
					uidKey: '_id',
					dateKey: [{ from: 'recorded' }],
					supportsLatest: true,
					defaults: {
						name: 'Glucose',
						valueQuantity: {
							units: 'mg/dl'
						}
					}
				},
				dependency: {
					linkTitles: {
						GET: 'observations-glucose',
						POST: 'observations'
					}
				},
				collection: {
					name: 'observation',
					objectType: 'Observations'
				}
			}
		},
		'bp-pulse' : {
			extensions : {
				object : {
					uidKey: '_id',
					dateKey : [{ from : 'updated' }],
					supportsLatest: true,
					defaults: {
						name: 'BloodPressureAndPulse',
						method: '',
						entry: [
							{
								valueQuantity: {
									units: 'mmHg'
								},
								name: '8480-6'
							},
							{
								valueQuantity: {
									units: 'mmHg'
								},
								name: '8462-4'
							},
							{
								valueQuantity: {
									units: 'bpm'
								},
								name: '8867-4'
							}
						]
					}
				},
				dependency : {
					linkTitles : {
						GET : 'vital-signs-bundle-bp',
						POST : 'vital-signs-bundle'
					}
				},
				collection : {
					name : 'observation',
					objectType : 'ObservationBundles'
				}
			}
		},
		'weight' : {
			extensions : {
				object : {
					uidKey: '_id',
					dateKey : [{ from : 'recorded' }],
					supportsLatest: true,
					defaults : {
						name : 'Weight',
						valueQuantity: {
							units: 'lbs'
						}
					}
				},
				dependency : {
					linkTitles : {
						GET : 'vital-signs-weight',
						POST : 'vital-signs'
					}
				},
				collection : {
					name: 'observation',
					objectType: 'Observations'
				}
			}
		},
		'kidney-journal' : {
			extensions : {
				object : {
					uidKey: '_id',
					dateKey : [{ from : 'recorded' }],
					supportsLatest: false,
					notesKey : 'body',
					defaults : {
         				type : 'Kidney Journal'
					}
				},
				dependency : {
					linkTitles : {
						GET : 'patient-notes-kidney-journal',
						POST : 'patient-notes'
					}
				},
				collection : {
					name: 'patientNote',
					objectType: 'PatientNotes'
				}
			}
		}
	});

	app.constant('TrackersRemindersConstants', {
		'bp-pulse-reminders': {
		   dependency : {
                linkTitles : {
                    GET : 'reminders-bp-pulse',
                    POST : 'reminders'
                }
            },
            object : {
                defaults : {
                    source : 'MobileKidney - Kidney Trackers - Blood Pressure and Pulse'
                }
            }
		},
		'glucose-reminders': {
		   dependency : {
                linkTitles : {
                    GET : 'reminders-glucose',
                    POST : 'reminders'
                }
            },
            object : {
                defaults : {
                     source : 'MobileKidney - Kidney Trackers - Glucose'
                }
            }
		},
		'weight-reminders': {
		   dependency : {
                linkTitles : {
                    GET : 'reminders-weight',
                    POST : 'reminders'
                }
            },
            object : {
                defaults : {
                     source : 'MobileKidney - Kidney Trackers - Weight'
                }
            }
		},
		'kidney-journal-reminders': {
		   dependency : {
                linkTitles : {
                    GET : 'reminders-kidney-journal',
                    POST : 'reminders'
                }
            },
            object : {
                defaults : {
                     source : 'MobileKidney - Kidney Trackers - Kidney Journal'
                }
            }
		}
	});
});