define(['angular', 'app'], function(angular, app) {
	app.constant('TrackersConstants', {
		'glucose': {
			summary: {
				table : {
					columns : [
						{ label: 'Glucose Level (mg/dl)', keys: 'valueQuantity.value' },
						{ label: 'Tested', keys: 'method', class: {column: 'hidden-xs'} },
						{ label: 'Date/Time', keys: 'recorded' },
						{ label: 'Note', keys: 'notes', cellTemplate: 'src/modules/trackers/pages/summary/partials/_notes-icon.html', class: { column: "hidden-xs" } }
					]
				},
				testConditions: ["Fasting (8 hours)", "After Meal", "Unknown"]
			},
			entry: {
				entryInputsTemplate : 'src/modules/trackers/pages/entry/partials/_glucose.html',
				vitalObservationsMeta:[
					{
						label : "Glucose Level",
						units : "mg/dl",
						min : "0",
						max : "600",
						validationExpression : /(^0?[1-9][0-9]$)|(^[1-5][0-9]{2}$)|(^600$)/,
						userInputPattern : /(^[1-9][0-9]{0,2}$)|(^0$)/
					}
				],
				testConditions: ["Fasting (8 hours)", "After Meal", "Unknown"]
			},
			name: 'Glucose'
		},
		'bp-pulse': {
			summary : {
				table : {
					columns : [
						{label: "Systolic (mmHg)", keys: "entry[0].valueQuantity.value"},
						{label: "Diastolic (mmHg)", keys: "entry[1].valueQuantity.value"},
						{label: "Pulse (bpm)", keys: "entry[2].valueQuantity.value"},
						{label: "Position", keys: "method", class: {column: "hidden-xs"}},
						{label: "Date/Time", keys: "updated"},
						{label: 'Note', keys: 'notes', cellTemplate: 'src/modules/trackers/pages/summary/partials/_notes-icon.html', class: { column: "hidden-xs" } }
					]
				}
			},
			entry : {
				entryInputsTemplate : "src/modules/trackers/pages/entry/partials/_bp-pulse.html",
				method : {
					label : "Position",
					options : [ "Standing", "Sitting", "Lying" ]
				},
				vitalObservationsMeta:[
					{
						label : "Systolic",
						units : "mmHg",
						min : "60",
						max : "300",
						validationExpression : /(^0?[89][0-9]$)|(^[12][0-9]{2}$)|(^300$)/,
						userInputPattern : /(^[1-9][0-9]{0,2}$)|(^0$)/
					},
					{
						label : "Diastolic",
						units : "mmHg",
						validationExpression : /(^0?[89][0-9]$)|(^[12][0-9]{2}$)/,
						userInputPattern : /(^[1-9][0-9]{0,2}$)|(^0$)/
					},
					{
						label : "Pulse",
						units : "bpm",
						min : "20",
						max : "250",
						validationExpression : /(^0?[4-9][0-9]$)|(^1[0-9]{2}$)|(^2[0-4][0-9]$)|(^250$)/,
						userInputPattern : /(^[1-9][0-9]{0,2}$)|(^0$)/
					}
				]
			},
			name: "Blood Pressure and Pulse"
		},
		"weight" : {
			summary : {
				table : {
					columns : [
						{label: "Weight (lbs)", keys: "valueQuantity.value"},
						{label: "Date/Time", keys: "recorded"},
						{label: 'Note', keys: 'notes', cellTemplate: 'src/modules/trackers/pages/summary/partials/_notes-icon.html'}
					]
				}
			},
			entry : {
				entryInputsTemplate : "src/modules/trackers/pages/entry/partials/_weight.html",
				vitalObservationsMeta:[
					{
						label : "Weight",
						units : "lbs",
						min : "0.0",
						max : "999.9",
						validationExpression : /^[0-9]{0,3}([.][0-9])?$/,
						userInputPattern : /^[1-9][0-9]{0,2}([.][0-9]?)?$|(^0([.][0-9]?)?$)/
					}
				]
			},
			name: "Weight"
		},
		"kidney-journal" : {
			summary : {
				table : {
					columns : [
						{label: "Title", keys: "title"},
						{label: "Date/Time", keys: "recorded"},
						{label: 'Follow-Up', keys: 'followUp', cellTemplate: 'src/modules/trackers/pages/summary/partials/_follow-up-icon.html', class: { column: "hidden-xs" } }
					]
				}
			},
			entry : {
				entryInputsTemplate : "src/modules/trackers/pages/entry/partials/_kidney-journal.html",
				instructionsTemplate : "src/modules/trackers/pages/entry/partials/_kidney-journal-instructions.html"
			},
            name: "Kidney Journal"
		}
	});
});