define(['angular', 'app', 'lodash', 'moment'], function (angular, app) {
	'use strict';

	app.controller('TrackersEntryController', function ($scope, $state, $stateParams, $filter, $parse, TrackersConstants, TrackersServiceConstants, TrackersService, TrackersRemindersService) {
		var service = TrackersService.instance($stateParams.section);

		$scope.section = $stateParams.section;
		angular.extend($scope, TrackersConstants[$stateParams.section].entry);
		
		$scope.notificationDetails = {
			notificationStatus: ''
		};

		TrackersRemindersService.init($stateParams.section);
		TrackersRemindersService.getReminder(TrackersConstants[$stateParams.section].name).then(function (response) {
			$scope.notificationDetails = angular.copy(response);
		});

		$scope.entryForm = {
			service: service,
			callbacks: {
				common: function () {
					$state.go($state.current.data.backState, $stateParams);
				}
			},
			allowedActions: {
				save: true,
				delete: !!$stateParams.id,
				cancel: true
			}
		};

		$scope.errorHandling = {
			'uniqueDateTime': {
				message: 'An entry has already been saved with the same date and time. Please change your date and/or time and save again.',
				priority: 1
			}
		};

		if ($stateParams.section === 'bp-pulse') {
			$scope.errorHandling['validBP'] = {
				message: 'The Systolic (mmHg) value must be greater than the Diastolic (mmHg) value. Please check the values and re-enter.',
				priority: 1
			}

			$scope.$watch("[details.entry[0].valueQuantity.value, details.entry[1].valueQuantity.value]", function(curVal, prevVal){
				if(!angular.equals(curVal, prevVal) && $scope.trackerForm) {
					var systolic = curVal[0],
					    diastolic = curVal[1],
					    valid = !systolic || !diastolic || parseInt(systolic) > parseInt(diastolic);

					$scope.trackerForm.specialErrors.$setValidity("validBP", valid);
				}
			}, true);
		}

		var minDate = moment().subtract(6, 'year').format('L');
		$scope.allowedDateRange = { min: minDate };

		$scope.sectionTitle = $filter('filter')($state.current.data.paramSections, { paramValue: $stateParams.section }, true)[0].sectionName;
		$scope.details = $stateParams.id ? angular.copy(service.localGetById($stateParams.id)) : service.createEmpty();
		
		var updated = $scope.details.lastModifiedDate || $scope.details.createdDate;
		if (updated) {
			$scope.details.updated = moment(updated, 'MM/DD/YYYY HH:mm:ss').toDate();
		}

		if ($stateParams.section === 'glucose') {
			$scope.details.numericValue = !$scope.details.valueQuantity.value || !isNaN($scope.details.valueQuantity.value);
			$scope.details.valueQuantity.units = $scope.details.numericValue ? 'mg/dl' : 'NA';

			$scope.$watch("details.numericValue", function(curVal, prevVal) {
				if (curVal !== prevVal) {
					$scope.details.valueQuantity.units = curVal ? 'mg/dl' : 'NA';
					$scope.details.valueQuantity.value = '';
				}
			}, true);
		}
	});
});