define([
		'app',
        'GraphService',
		'TrackersService',
        'TrackersConstants',
        'TrackersServiceConstants',
		'AbstractTrackersService',
		'TrackersSummaryController',
		'TrackersEntryController',
        'RemindersService',
        'NotificationDeliveryDirective',
        'TrackerNavItemDateFilter',
        'TrackersNavController',
        'TrackersNotificationStatusController',
        'TrackersRemindersService',
        'TrackersRemindersInstanceService'
	],
	function (app) {
		"use strict";

		app.config(function ($stateProvider) {
			$stateProvider
				.state('main.auth.two-panel.secondary-navigation.trackers', {
					url: '/trackers',
					appNavIndex: 2,
					data: {
						moduleName: "Kidney Trackers",
						panel: "secondary",
                        baseStateName : 'main.auth.two-panel.secondary-navigation.trackers',
                        initialState : "summary",
                        paramSections : [
                            {
                                paramValue : "bp-pulse",
                                sectionName : "Blood Pressure and Pulse",
                                sectionIndex : 1,
                                iconClass : "icon-health-bloodpressure",
                                templateUrl : "src/modules/trackers/pages/nav/bp-pulse_item.html"
                            }, {
                                paramValue : "weight",
                                sectionName : "Weight",
                                sectionIndex : 2,
                                iconClass : "icon-health-weight",
                                templateUrl : "src/modules/trackers/pages/nav/weight_item.html"
                            }, {
                                paramValue : "glucose",
                                sectionName : "Glucose",
                                sectionIndex : 3,
                                iconClass : "icon-health-glucose",
                                templateUrl : "src/modules/trackers/pages/nav/glucose_item.html"
                            }, {
                                paramValue : "kidney-journal",
                                sectionName : "Kidney Journal",
                                sectionIndex : 4,
                                iconClass : "icon icon-journal",
                                templateUrl : "src/modules/trackers/pages/nav/journal_item.html"
                            }
                        ]
					},
					views : {
						'primary@main.auth.two-panel': {
							templateUrl: 'src/modules/trackers/pages/trackers-placeholder_template.html',
                            controller: 'TrackersNavController'
						}
					}
				})
                .state('main.auth.two-panel.secondary-navigation.trackers.summary', {
                    url: '/{section:bp-pulse|weight|glucose|kidney-journal}/summary',
                    data: {
                        panel : "primary",
                        backState : "^"
                    },
                    views : {
                        'primary@main.auth.two-panel': {
                            templateUrl: 'src/modules/trackers/pages/summary/trackers-summary_template.html',
                            controller: 'TrackersSummaryController'
                        }
                    }
                })
                .state('main.auth.two-panel.secondary-navigation.trackers.entry', {
                    url: '/{section:bp-pulse|weight|glucose|kidney-journal}/entry?id',
                    data : {
                        panel : "primary",
                        backState : "^.summary"
                    },
                    views : {
                        'primary@main.auth.two-panel': {
                            templateUrl: 'src/modules/trackers/pages/entry/trackers-entry_template.html',
                            controller: 'TrackersEntryController'
                        }
                    }
                })
                .state('main.auth.two-panel.secondary-navigation.trackers.notification', {
                    url: '/{section:bp-pulse|weight|glucose|kidney-journal}/notification',
                    data: {
                        panel: 'primary',
                        backState: '^.summary'
                    },
                    views: {
                        'primary@main.auth.two-panel': {
                            templateUrl: 'src/modules/trackers/pages/notification-status/trackers-notification-status_template.html',
                            controller: 'TrackersNotificationStatusController'
                        }
                    }
                });
		});
	}
);
