define([
		'app',
		'eula_service',
		'resourcedirectory_service',
		'authentication_service',
		'mhpuser_service',
		'patient',
		'connection_error_service',
		'connection_timeout_service',
		'modalService',
		'NotificationsPreferencesService',
		'EulaController',
		'SplashController',
		'HeaderController',
		'FooterController',
		'MainController',
		'HelpController',
		'AboutController',
		'accessibleDatePickerServices',
		'DateControls',
		'highcharts-ng',
		'SecondaryNavigationController',
		'HomeModule',
		'LearnMoreModule',
		'KnowledgeCheckModule',
		'TrackersModule',
		'NotificationsModule'
	],
	function (app) {
		"use strict";

		app.config(function ($stateProvider, unsavedWarningsConfigProvider) {

			$stateProvider
				.state('main', {
					abstract: true,
					data: {
						moduleName: "MobileKidney",
						requiresAuth: true
					},
					views: {
						"": {
							templateUrl: 'src/container/main/main_template.html',
							controller: 'MainController'
						},
						'header@main': {
							templateUrl: 'src/container/components/header/header_template.html',
							controller: 'HeaderController'
						},
						'footer@main': {
							templateUrl: 'src/container/components/footer/footer_template.html',
							controller: 'FooterController'
						}
					},
					resolve: {
						token: function ($q, $location, authenticationService) {
							var defer = $q.defer(),
								currentUrl = $location.absUrl(),
								regExpr = new RegExp("[?&]token=" + authenticationService.getCurrentToken());

							!regExpr.test(currentUrl) ? defer.resolve() : defer.reject({ error: 'token', redirect: currentUrl.replace(regExpr, "")});

							return defer.promise;							
						},
						eula: function ($q, eulaService) {
							var defer = $q.defer();
							
							eulaService.isAccepted() ? defer.resolve() : defer.reject({ error: 'eula' });

							return defer.promise;
						}
					}
				})
				.state('main.auth', {
					abstract: true,
					resolve: {
						auth: function ($q, pageService, authenticationService, mhpuser, NotificationsPreferencesService) {
							var defer = $q.defer();

							authenticationService.checkAuthStatus().then(function (status) {
								if(status) {
									mhpuser.fetch().then(function (user) {
										if (!pageService.isRoaAccepted(user))
											defer.reject({ error: 'roa', redirect: pageService.getROAUrl() });
										else if (NotificationsPreferencesService.isPreferenceStored() === false)
											defer.reject({ error: 'initial-settings' });
										else if (NotificationsPreferencesService.isPreferenceStored() === null ) {
											return NotificationsPreferencesService.getNotificationsPreference().then(
												function() {
													defer.resolve();
												},
												function(error) {
													if(error.errorType === "204") {
														defer.reject({ error: 'initial-settings' });
													}
												}
											);
										} else
											defer.resolve();
									});
								} else {
									defer.reject({ error: 'auth' });
								}
							});

							return defer.promise;
						}
					}
				})
				.state('main.auth.two-panel', {
					abstract: true,
					views: {
						'@main': {
							templateUrl: 'src/container/components/content/two-column_template.html',
							controller: 'TwoPanelController'
						}						
					}
				})
				.state('main.auth.two-panel.secondary-navigation', {
					abstract: true,
					views : {
						'secondary@main.auth.two-panel' : {
							templateUrl: "src/container/components/content/secondary-navigation/secondary-navigation_template.html",
							controller: "SecondaryNavigationController"
						}
					}
				})
				.state('main.splash', {
					url: '/login',
					data : {
						requiresAuth: false
					},
					templateUrl: 'src/container/splash/splash_template.html',
					controller: 'SplashController',
					module: 'preventNavigation'
				})
				.state('eula', {
					url: '/eula',
					data: {
						moduleName: "MobileKidney",
						requiresAuth: false
					},
					templateUrl: 'src/core/eula/eula_template.html',
					controller: 'EulaController'
				})
				.state('nonStateRedirect', {
					url: '/redirecting'
				});

			unsavedWarningsConfigProvider.useTranslateService = false;
		});

		app.run(function ($rootScope, $state, $window, resourceDirectory, pageService, connectionErrorService) {

			connectionErrorService.run();
			resourceDirectory.fetch();

			$rootScope.$on('$stateChangeError', function (event, toState, toParams, fromState, fromParams, error) {

				if (error.redirect) {
					$state.go('nonStateRedirect');
					$window.open(error.redirect, '_self', null, true);
				} else {
					switch (error.error) {
						case 'eula':
							$state.go('eula');
							break;
						case 'auth': 
							$state.go('main.splash');
							break;
						case 'initial-settings': 
							$state.go('main.initial-settings');
							break;
					}
				}

			});
		});
	});