#!/bin/env ruby
# encoding: utf-8

require 'rubygems'
require 'rspec'
require 'watir-webdriver'
require 'page-object'
require 'spreadsheet'

require_relative '../rspec_helper'
require_relative '../../lib/pages/login_page'
require_relative '../../lib/pages/eula'
require_relative '../../lib/pages/landing_page'
require_relative '../../lib/pages/roa'
require_relative '../../lib/pages/launchpad'
require_relative '../../lib/pages/common_elements'
require_relative '../../lib/pages/common_tests'
require_relative '../../lib/pages/modal_dialog'
require_relative '../../lib/pages/left_side_nav'
require_relative '../../lib/pages/learn_more_accordions'


describe 'Story#CKD-268 Nutrition_Get_Right_Amount_Protein_Content_CKD_268_spec.rb', :regression=>true do
  include DriverUtility

  headingName = "Get the Right Amount of Protein"

  before(:all) do

    initializeConfigurations(BASE_URL)

    @commonElements = CommonElement.new(@driver)
    @loginpage = LoginPage.new(@driver)
    @eula = Eula.new(@driver)
    @landing = LandingPage.new(@driver)
    @roa = Roa.new(@driver)
    @leftnav = LeftSideNav.new(@driver)
    @lp = Launchpad.new(@driver)
    @commonTest = CommonTest.new(@driver)
    @modal = Modal.new(@driver)
    @lmAccd = LearnMoreAccd.new(@driver)


    @commonTest.passByLandingPageAndAuthenticate("zztest.patient01", "pass", "patient01, zztest", "D123401")

    @commonTest.waitForContentLoaded
    @leftnav.leftSideNav

    # @leftnav.home_element.when_visible
    #
    # @leftnav.learnMore
    # @commonElements.secondaryHeader_element.when_visible(timeout=10)
    #
    #
    # @leftnav.kidneyInfo
    # @commonElements.primaryHeader_element.when_visible(timeout=10)

    @commonTest.navigateToAsubFeature("LearnMore", ".nutrition")

    #Expand the "Get the Right Amount of Protein" accordion
    @leftnav.clickAccordion(1)
    sleep 0.5
  end


  after(:all) do
    @driver.close
  end


  dataSheetFilePath = File.dirname(__FILE__) + '/../../datasheet/Nutrition_Text_Content.xls'
  book = Spreadsheet.open dataSheetFilePath
  sheet1 = book.worksheet 'getRightAmtOfProtein'

  counter = 0
  sheet1.each 1 do |row|
    counter = counter + 1
    #Below three lines are used to debug data-sheet row by row
    # if counter > 1
    #   break
    # end


    rowLength = row.length
    # puts "row[].length=" + row.length.to_s

    sectionID = row[0].to_i
    # puts "sectionID=" + sectionID.to_s
    expectedImageInfo = row[2].split(/\r?\n/)
    expectedImgName = expectedImageInfo.first
    expectedImgAcknowledgement = ""
    if expectedImageInfo.length > 1
      expectedImgAcknowledgement = expectedImageInfo.last
    end
    # puts "expectedImgName=" + expectedImgName
    expectedImgAltName = row[3]
    # puts "expectedImgAltName=" + expectedImgAltName
    expectedSectionHeader = row[4]
    # puts "expectedSectionHeader=" + expectedSectionHeader


    context 'Story#CKD-269~278|TC#CKD-815: Image and content for this section displays correctly - ' + expectedSectionHeader do

      if row[2] != "na"
        it '. Verify the image file name is correct: ' do
          if @lmAccd.getImgtUnderEachSection(sectionID, headingName).include?(expectedImgName) == false
            puts "Different! Failed sectionID=" + sectionID.to_s + "; Displayed Img=" + @lmAccd.getImgtUnderEachSection(sectionID, headingName)
          end
          expect(@lmAccd.getImgtUnderEachSection(sectionID, headingName).include?(expectedImgName)).to eq(true)

        end

        it '. Verify that the image has the correct alt text. ' do
          expect(@lmAccd.getImgAltTextUnderEachSection(sectionID, headingName).include?(expectedImgAltName)).to eq(true)
        end

        it '. Verify the image acknowledgement is correct: ' do
          expect(@lmAccd.getImgAcknowledgementUnderEachSection(sectionID, headingName)).to eq(expectedImgAcknowledgement)
        end

        it '. Click the image and verify it opens up in a modal screen. ' do

          @lmAccd.clickImgtUnderEachSection(sectionID, headingName)
          @modal.imgTitle_element.when_visible(timeout=10)
          expect(@modal.imgTitle).to eq(expectedSectionHeader)
          expect(@modal.closeImg?).to eq(true)
          @modal.closeImg
          @modal.imgTitle_element.when_not_visible
          expect(@modal.imgTitle?).to eq(false)

        end



        it '. Verify that the segment header displays correctly. ' do
          $bodyContent = @lmAccd.getBodyContentUnderEachSection(sectionID, headingName)
          # puts "$bodyContent=" + $bodyContent
          expect($bodyContent.include?(expectedSectionHeader)).to eq(true)
        end

        it '. Verify the in Phone form factor, the image does not display' do

          #Reset to Phone size
          resizeWindowTo(320, 480)
          sleep 1
          expect(@lmAccd.isImgPresent(sectionID, headingName)).to eq(false)
          #Reset to the default size
          resizeWindowToDefault()

        end

        for column in 5..rowLength-1

          segmentName = "text Part " + (column-4).to_s
          expectedSegContent = row[column].strip
          # puts "expectedSegContent=" + expectedSegContent

          it '. Verify that all segments under this section displays correctly - ' + segmentName do
            $bodyContent = @lmAccd.getBodyContentUnderEachSection(sectionID, headingName)
            if $bodyContent.include?(expectedSegContent) == false
              puts "This part has discrepancy. See below"
              puts expectedSegContent
              puts "bodyContent=" + $bodyContent
            end
            expect($bodyContent.include?(expectedSegContent)).to eq(true)

          end


        end

      else

        it '. Verify the Knowledge Check text displays ' do
          $bodyContent = @lmAccd.getBodyContentUnderEachSection(sectionID, headingName)
          # puts "$bodyContent=" + $bodyContent
          # puts "expectedSectionHeader=" + expectedSectionHeader
          expect($bodyContent.include?(expectedSectionHeader)).to eq(true)
        end

      end

    end

  end

end

